# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
"""
Contains the implementation of the Business Analyst dataset discovery methods
"""

__all__ = [
    "ListDatasets",
    "ListVariables"
    ]

import os, platform, sys, unittest, time, re

if sys.platform.startswith("win"):
    try:
        import winreg
    except ImportError:
        # py 2
        import _winreg as winreg

import xml.etree.ElementTree as ET
from contextlib import suppress
import itertools


def get_dataset_setting(dataset, setting):
    reg = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, r"SOFTWARE\WOW6432Node\ESRI\BusinessAnalyst\Datasets\{0}".format(dataset))
    return winreg.QueryValueEx(reg, setting)[0]

def subkeys(path, hkey, flags=0):
    with suppress(WindowsError), winreg.OpenKey(hkey, path, 0, winreg.KEY_READ|flags) as k:
        for i in itertools.count():
            yield winreg.EnumKey(k, i)

def get_out_field_name(ge_field_name):
    out_field_name = ge_field_name.replace(".", "_")
    out_field_name = re.sub(r"(^\d+)", r"F\1", out_field_name) # if string starts with a set of digits, replace them with Fdigits
    return out_field_name
            
class CountryInfo:
    def __init__(self, dataset_description_file = None, name = None, iso2 = None, iso3 = None):
        if dataset_description_file:
            tree = ET.parse(dataset_description_file)
            root = tree.getroot()
            country = root.find("country")
            self.ISO2 = country.attrib["iso2"]
            self.ISO3 = country.attrib["iso3"]
            self.Name = country.attrib["name"]
        else:
            self.ISO2 = iso2
            self.ISO3 = iso3
            self.Name = name

class Dataset:
    def __init__(self, id):
        self.ID = id
        data_install_dir = get_dataset_setting(id, "DataInstallDir")
        settings_file = get_dataset_setting(id, "SettingsFile")
        
        tree = ET.parse(settings_file)
        root = tree.getroot()
        
        self.Caption = root.attrib["caption"]
        
        dataset_description_file = os.path.join(data_install_dir, "dataset_description.xml")
        
        if os.path.isfile(dataset_description_file):
            # load from file
            self.CountryInfo = CountryInfo(dataset_description_file)
        else:
            # special case for Canada
            try:
                country, _, year = re.match(r'([^_]*)_?([^_]*)_?(\d{4})', id).groups()
                if country == "CAN":
                    self.CountryInfo = CountryInfo(name = "Canada", iso2 = "CA", iso3 = "CAN")
                else:
                    self.CountryInfo = None
            except:
                self.CountryInfo = None

        self.DataSourceID = "LOCAL;;{0}".format(id)
        
        self.Version = root.attrib["version"]
        
class Variable:
    def __init__(self, data_collection, name, alias):
        self.Name = name
        self.FullName = data_collection + "." + name
        self.Alias = alias
        self.DataCollectionID = data_collection
        self.OutputFieldName = get_out_field_name(self.FullName)

def ListDatasets():
    if not sys.platform.startswith("win"):
        raise Exception('ListDatasets is only supported on Windows')

    path = r"SOFTWARE\WOW6432Node\ESRI\BusinessAnalyst\Datasets"
    
    for dataset_id in subkeys(path, hkey=winreg.HKEY_LOCAL_MACHINE):
        yield Dataset(dataset_id)


def ListVariables(dataset, include_derivatives = False):
    if not sys.platform.startswith("win"):
        raise Exception('ListVariables is only supported on Windows')

    if isinstance(dataset, Dataset):
        dataset_id = dataset.ID
    else:
        dataset_id = dataset
    
    dc_folder = get_dataset_setting(dataset_id, "DataCollectionsDir")
    
    for f in os.listdir(dc_folder):
        dc_file = os.path.join(dc_folder, f)
        
        try:
            tree = ET.parse(dc_file)
        except:
            continue
        
        root = tree.getroot()
        if root.tag == "DataCollection":
            dc_name = root.find("Metadata/name").text
            # there's EPList.xml that is not a data collection
            calculators = root.find("Calculators")
            for c in calculators:
                fields = c.findall("Fields/Field")
                for f in fields:
                    if "HideInDataBrowser" in f.attrib:
                        if f.attrib["HideInDataBrowser"] == "True":
                            continue # skip hidden variables

                    yield Variable(dc_name, f.attrib["Name"], f.attrib["Alias"])

                    if not include_derivatives:
                        continue
                        
                    if "PercentBase" in f.attrib:
                        if f.attrib["PercentBase"]: # not null or empty
                            yield Variable(dc_name, f.attrib["Name"] + "_P", f.attrib["Alias"] + " Percent")
                    if "IndexBaseValue" in f.attrib:
                        if f.attrib["IndexBaseValue"]: # not null or empty
                            yield Variable(dc_name, f.attrib["Name"] + "_I", f.attrib["Alias"] + " Index")
                    if "AverageBase" in f.attrib:
                        if f.attrib["AverageBase"]: # not null or empty
                            yield Variable(dc_name, f.attrib["Name"] + "_A", f.attrib["Alias"] + " Average")