# -*- coding: utf-8 -*-
#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
from arcpy import gp
from arcpy.arcobjects.arcobjects import Geometry
import arcpy
import operator
import json

try:
    xrange, basestring
except NameError:
    xrange, basestring = range, str

__all__ = ['Annotation', 'Dimension', 'Multipatch', 'Multipoint', 'PointGeometry', 'Polygon', 'Polyline', 'AsShape',
           'FromCoordString', 'GenerateOptimalCoordinateSystem']

class Annotation(Geometry):
    __type_string__ = "annotation"

class Dimension(Geometry):
    __type_string__ = "dimension"

class Multipatch(Geometry):
    __type_string__ = "multipatch"

class Multipoint(Geometry):
    """Multipoint objects are ordered collection of points."""
    __type_string__ = "multipoint"
    def __iter__(self):
        for x in xrange(self.partCount):
            yield self.getPart(x)
    @property
    def __geo_interface__(self):
        return {'type': 'Multipoint', 'coordinates': [(pt.X, pt.Y) for pt in self]}
    @classmethod
    def _fromGeoJson(cls, data):
        from arcpy.arcobjects.arcobjects import Point, Array
        coordkey = ([d for d in data if d.lower() == 'coordinates']
                     or ['coordinates']).pop()
        coordinates = data[coordkey]
        return cls(Array([Point(*p) for p in coordinates]), arcpy.SpatialReference(4326))

    def __getSVG__(self, scale_factor=1., fill_color=None):
        """Returns SVG circle elements for MultiPoint geometry.

        Parameters
        ==========
        scale_factor : float
            Multiplication factor for the SVG circle diameters. Default is 1.
        fill_color : str, optional
            Hex string for fill color. Default is to use "#66cc99"
        """
        if fill_color is None:
            fill_color = "#66cc99"
        return '<g>' + \
               ''.join(('<circle cx="{0}" cy="{1}" r="{2}" '
                        'stroke="#555555" stroke-width="{3}" fill="{4}" opacity="0.6" />'
                        ).format(p[0], p[1], 3 * scale_factor, 1 * scale_factor, fill_color) \
                       for p in json.loads(self.JSON)['points']) + \
               '</g>'

class PointGeometry(Geometry):
    """A PointGeometry is a shape that has neither length nor area at a given
       scale."""
    __type_string__ = "point"
    @property
    def __geo_interface__(self):
        return {'type': 'Point', 'coordinates': (self.getPart(0).X,
                                                 self.getPart(0).Y)}
    @classmethod
    def _fromGeoJson(cls, data):
        from arcpy.arcobjects.arcobjects import Point
        coordkey = ([d for d in data if d.lower() == 'coordinates']
                     or ['coordinates']).pop()
        coordinates = data[coordkey]
        return cls(Point(*coordinates), arcpy.SpatialReference(4326))
    
    def __getSVG__(self, scale_factor=1, fill_color=None):
        """Returns SVG circle element for Point geometry.

        Parameters
        ==========
        scale_factor : float
            Multiplication factor for the SVG circle diameter. Default is 1.
        fill_color : str, optional
            Hex string for fill color. Default is to use "#66cc99"
        """
        if fill_color is None:
            fill_color = "#66cc99"
        return (
            '<circle cx="{0.X}" cy="{0.Y}" r="{1}" '
            'stroke="#555555" stroke-width="{2}" fill="{3}" opacity="0.6" />'
            ).format(self.getPart(), 3 * scale_factor, 1 * scale_factor, fill_color)
    
    def toCoordString(self, notation):
        """PointGeometry.toCoordString({notation})"""
        from arcpy.geoprocessing._base import gp_fixargs
        from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
        return convertArcObjectToPythonObject(self._arc_object.toCoordString(*gp_fixargs((notation,))))

class Polygon(Geometry):
    """A Polygon object is a closed shape defined by a connected sequence of x,y
       coordinate pairs."""
    __type_string__ = "polygon"
    def __iter__(self):
        for x in xrange(self.partCount):
            yield self.getPart(x)
    @property
    def __geo_interface__(self):
        def split_part(a_part):
            part_list = []
            for item in a_part:
                if item is None:
                    if part_list:
                        yield part_list
                    part_list = []
                else:
                    part_list.append((item.X, item.Y))
            if part_list:
                yield part_list
        part_json = [list(split_part(part))
                     for part in self]
        return {'type': 'MultiPolygon', 'coordinates': part_json}
    @classmethod
    def _fromGeoJson(cls, data):
        from arcpy.arcobjects.arcobjects import Point, Array
        coordkey = ([d for d in data if d.lower() == 'coordinates']
                     or ['coordinates']).pop()
        coordinates = data[coordkey]
        typekey = ([d for d in data if d.lower() == 'type']
                     or ['type']).pop()
        if data[typekey].lower() == "polygon":
            coordinates = [coordinates]
        part_list = []
        for part in coordinates:
            part_item = []
            for idx, ring in enumerate(part):
                if idx:
                    part_item.append(None)
                for coord in ring:
                    part_item.append(Point(*coord))
            if part_item:
                part_list.append(Array(part_item))
        return cls(Array(part_list), arcpy.SpatialReference(4326))
    
    def __getSVG__(self, scale_factor=1, fill_color=None):
        """Returns SVG path element for Polygon geometry.

        Parameters
        ==========
        scale_factor : float
            Multiplication factor for the SVG stroke-width. Default is 1.
        stroke_color : str, optional
            Hex string for stroke color. Default is "#66cc99"
        """
        if fill_color is None:
            fill_color = "#66cc99"
        rings = []

        geom_json = json.loads(self.JSON)

        if 'rings' not in geom_json:
            densify_geom = self.densify('ANGLE', -1, 0.1)
            geom_json = json.loads(densify_geom.JSON)

        if not geom_json['rings']:  # empty rings
            return '<g />'

        path = ''

        for ring in geom_json['rings']:
            path += ' M {},{}'.format(*ring[0])
            for x, y in ring[1:]:
                path += ' L {},{}'.format(x, y)

        path += ' z'

        return (
            '<path fill-rule="evenodd" fill="{2}" stroke="#555555" '
            'stroke-width="{0}" opacity="0.6" d="{1}" />'
            ).format(2. * scale_factor, path, fill_color)

class Polyline(Geometry):
    """A Polyline object is a shape defined by one or more paths, in which a
       path is a series of connected segments."""
    __type_string__ = "polyline"
    def __iter__(self):
        for x in xrange(self.partCount):
            yield self.getPart(x)
    @property
    def __geo_interface__(self):
        return {'type': 'MultiLineString', 'coordinates': [[((pt.X, pt.Y) if pt else None)
                                                                for pt in part]
                                                                    for part in self]}
    @classmethod
    def _fromGeoJson(cls, data):
        from arcpy.arcobjects.arcobjects import Point, Array
        coordkey = ([d for d in data if d.lower() == 'coordinates']
                     or ['coordinates']).pop()
        if data['type'].lower() == 'linestring':
            coordinates = [data[coordkey]]
        else:
            coordinates = data[coordkey]
        return cls(Array([[Point(*p) for p in part] for part in coordinates]),
                   arcpy.SpatialReference(4326))
    
    def __getSVG__(self, scale_factor=1, stroke_color=None):
        """Returns SVG polyline element for Polyline geometry.

        Parameters
        ==========
        scale_factor : float
            Multiplication factor for the SVG stroke-width. Default is 1.
        stroke_color : str, optional
            Hex string for stroke color. Default is "#66cc99"
        """

        import json

        if stroke_color is None:
            stroke_color = "#66cc99"
        paths = []

        geom_json = json.loads(self.JSON)

        if 'paths' not in geom_json:
            densify_geom = self.densify('DISTANCE', 1.0, 0.1)
            geom_json = json.loads(densify_geom.JSON)

        if not geom_json['paths']:  # empty paths
            return '<g />'

        for path in geom_json['paths']:
            pnt_format = " ".join(["{0},{1}".format(*c) for c in path])
            s = ('<polyline fill="none" stroke="{2}" stroke-width="{1}" '
                 'points="{0}" opacity="0.8" />').format(pnt_format, 2. * scale_factor, stroke_color)
            paths.append(s)
        return "<g>" + "".join(paths) + "</g>"

for cls in (Annotation, Dimension,
            Multipatch, Multipoint,
            PointGeometry, Polygon,
            Polyline):
    Geometry.__type_mapping__[cls.__type_string__] = cls

del cls

def AsShape(geojson_struct, esri_json=False):
    """AsShape(geojson_struct, {esri_json})

       Converts Esri JSON or GeoJSON to ArcPy geometry or feature set objects.
       GeoJSON is a geospatial data interchange format for encoding geographic
       data
       structures.

         geojson_struct(Dictionary):
       The geojson_struct includes type and coordinates .

       The following strings are  included for type : Point , LineString ,
       Polygon , MultiPoint , and MultiLineString .

         esri_json{Boolean}:
       Sets whether the input JSON is evaluated as Esri JSON or GeoJSON.  If
       True, the input is evaluated as Esri JSON."""
    if esri_json:
        if not isinstance(geojson_struct, basestring):
            geojson_struct = json.dumps(geojson_struct)
        from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
        return convertArcObjectToPythonObject(gp.fromEsriJson(geojson_struct))
    else:
        mappings = {
                        'point': PointGeometry,
                        'multipoint': Multipoint,
                        'polygon': Polygon,
                        'multipolygon': Polygon,
                        'multilinestring': Polyline,
                        'linestring': Polyline
                   }
        if isinstance(geojson_struct, basestring):
            geojson_struct = json.loads(geojson_struct)
        import arcpy
        assert isinstance(geojson_struct, dict),\
                arcpy.GetIDMessage(88023, 'Invalid Geometry Data')
        assert (geojson_struct.get('type', None) or '').lower() in mappings,\
                arcpy.GetIDMessage(88023, 'Invalid Geometry Data')
        return mappings[geojson_struct.get('type').lower()]._fromGeoJson(geojson_struct)

def FromCoordString(coordinate_str, notation):
    """FromCoordString(coordinate_str, notation)

    Convert string in various notation formats (aka notations): DD, DDM, DMS, GARS, GEOREF, UTM, USNG, MGRS to a
    PointGeometry.
    
     coordinate_str(string):
    A string in a certain format that represents the coordinates of a point.

     notation (string):
    A string represents the format of the coordinate_str. The following formats are supported: MGRS, USNG, UTM, UTMNS,
    GEOREF, GARS, DMS, DMS_1, DMS_2, DDM, DDM_1, DDM_2, DD, DD_1, DD_2, DD_NUMERIC.

    This function is going to return an instance of PointGeometry with spatial reference of WGS_1984.
    """
    from arcpy.geoprocessing._base import gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    return convertArcObjectToPythonObject(gp._arc_object.FromCoordString(*gp_fixargs((coordinate_str, notation))))

def GenerateOptimalCoordinateSystem(extent, property, custom_name=None):
    """GenerateOptimalCoordinateSystem(extent, property, {custom_name})

    Get a custom coordinate system that matches a specified extent and projection property.

     extent(Extent):
    An arcpy.Extent object that represents the extent of interest. The spatial reference of the extent needs to be in a
    geographic coordinate system.
     property(string):
    A string that represents the projection property of the custom projected coordinate system. The following properties
    are supported: equal_area, conformal, equidistant_one_point, equidistant_meridians, and compromise_world.
    equal_area, equidistant_one_point properties are supported for all extents of interest; conformal,
    equidistant_meridians properties are supported only for large-scale extents; and compromise_world property only
    supports full world extents.
     custom_name(string):
    A string that specifies the name of the custom projected coordinate system. The name will be "Custom_Projection" if
    not specified.

    This function returns an instance of SpatialReference with a custom projected coordinate system matching the
    specified extent and projection property.
    """
    from arcpy.geoprocessing._base import gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    return convertArcObjectToPythonObject(gp._arc_object.generateoptimalprojectedcoordinatesystem(*gp_fixargs((extent, property, custom_name))))
