# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Toolbox Aviation Tools"""
__all__ = ['AnalyzeAirportFeatures', 'AnalyzeLASRunwayObstacles',
           'AnalyzeRunwayObstacles', 'CreateCurvedApproach',
           'ExportFAA18BShapefiles', 'FAA13A', 'FAA18B', 'FAA2C', 'FAAFAR77',
           'GenerateAirspaceLines', 'GenerateAviationCartographicFeatures',
           'GenerateDerivedAirspaceGeometry', 'GenerateOISIntersection',
           'GenerateOISObstacleData', 'GenerateOISProfileData', 'ICAOAnnex14',
           'ICAOAnnex15', 'ICAOAnnex4', 'ImportAIXM51Message', 'ImportDOF',
           'ImportFAA18BShapefiles', 'LightSignalClearanceSurface',
           'PAPIObstacleClearanceSurface', 'PrepareAviationData',
           'ProcessAirTrafficServiceRoutes', 'ReportAviationChartChanges',
           'UnifiedFacilitiesCriteria']
__alias__ = 'aviation'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Airports\Analysis toolset
@gptooldoc('AnalyzeAirportFeatures_aviation', None)
def AnalyzeAirportFeatures(in_features=None, in_runway_features=None, out_table=None, in_features_height=None, in_features_height_unit=None, runway_end_features=None, airport_ref_point_features=None, ref_point_height=None, ref_point_height_unit=None):
    """AnalyzeAirportFeatures_aviation(in_features, in_runway_features, out_table, {in_features_height}, {in_features_height_unit}, {runway_end_features}, {airport_ref_point_features}, {ref_point_height}, {ref_point_height_unit})

        Analyzes specified point features around an airfield to find and
        record information such as distance from a given runway centerline or
        the end of the nearest runway, and the designation for that nearest
        runway.

     INPUTS:
      in_features (Feature Layer):
          The input point features that will be analyzed and recorded, in terms
          of their physical relationships to features in the other inputs.
      in_runway_features (Feature Layer):
          The input runway polyline features, specifically their centerlines,
          that will be used in the analysis.
      in_features_height {String}:
          The name of a field in the input airport features dataset. The
          specified field must contain numeric values. The values in this field
          will be used to identify the height of each input airport feature.

          * SHAPE_Z-Height values will be derived from the z-values of the input
          point features. This is the default.
      in_features_height_unit {String}:
          Specifies the linear unit of measure that will be used when the Input
          Features Height parameter is specified.

          * KILOMETERS-Kilometers

          * METERS-Meters

          * DECIMETERS-Decimeters

          * CENTIMETERS-Centimeters

          * MILLIMETERS-Millimeters

          * NAUTICAL_MILES-Nautical miles

          * MILES-Miles

          * YARDS-Yards

          * FEET-Feet

          * INCHES-Inches

          * DECIMAL_DEGREES-Decimal degrees

          * POINTS-Points

          * UNKNOWN-Unknown
      runway_end_features {Feature Layer}:
          The input runway end point features associated with the runways in the
          Input Features Height Unit parameter that represent the thresholds of
          those runways.
      airport_ref_point_features {Feature Layer}:
          The input airport reference point features that define the center
          point of an airport, located at the geometric center of all the usable
          runways and computed as a weighted average of the end of runway
          coordinates.
      ref_point_height {String}:
          The name of a field in the input airport reference point features
          dataset. The specified field must contain numeric values. The values
          in this field will be used to identify the height of each input
          airport reference point feature.

          * SHAPE_Z-The z-value of each point. This is the default.
      ref_point_height_unit {String}:
          The linear unit of measure that will be used when the airport
          reference point height is specified.

          * KILOMETERS-Kilometers

          * METERS-Meters

          * DECIMETERS-Decimeters

          * CENTIMETERS-Centimeters

          * MILLIMETERS-Millimeters

          * NAUTICAL_MILES-Nautical miles

          * MILES-Miles

          * YARDS-Yards

          * FEET-Feet

          * INCHES-Inches

          * DECIMAL_DEGREES-Decimal degrees

          * POINTS-Points

          * UNKNOWN-Unknown

     OUTPUTS:
      out_table (Table View):
          The output table, with a row for each input airport feature,
          containing the analytical results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AnalyzeAirportFeatures_aviation(*gp_fixargs((in_features, in_runway_features, out_table, in_features_height, in_features_height_unit, runway_end_features, airport_ref_point_features, ref_point_height, ref_point_height_unit), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AnalyzeLASRunwayObstacles_aviation', None)
def AnalyzeLASRunwayObstacles(in_ois_features=None, in_las_obstacles=None, out_obstacle_feature_class=None, target_folder=None, out_las_obstacles=None, vertical_clearance=None, vertical_clearance_unit=None):
    """AnalyzeLASRunwayObstacles_aviation(in_ois_features, in_las_obstacles, {out_obstacle_feature_class}, {target_folder}, {out_las_obstacles}, {vertical_clearance}, {vertical_clearance_unit})

        Analyzes lidar data and obstruction identification surfaces (OIS) to
        determine if lidar points are penetrating.

     INPUTS:
      in_ois_features (Feature Layer):
          The input multipatch features representing one or more OIS. The
          feature class must be z-enabled.
      in_las_obstacles (LAS Dataset Layer):
          The input LAS dataset that contains 3D data points covering the area
          around an airport. The points represent a 3D view of natural and man-
          made objects that could pose a hazard to flight.
      vertical_clearance {Double}:
          If a LAS point height is above the OIS surface, that point will be
          captured. The height of an OIS surface above a given LAS point is
          temporarily lowered by the specified vertical clearance value. This
          serves to decrease the distance between the height of the LAS point
          and the corresponding OIS surface, resulting in the likeliness that
          more points will be captured. Thus, you can be sure that a more
          liberal collection of ground features, represented by the LAS points
          penetrating through the OIS surface, will be captured.
      vertical_clearance_unit {String}:
          The linear unit of the vertical clearance.

          * KILOMETERS-The linear unit is kilometers.

          * METERS-The linear unit is meters.

          * DECIMETERS-The linear unit is decimeters.

          * CENTIMETERS-The linear unit is centimeters.

          * MILLIMETERS-The linear unit is millimeters.

          * NAUTICAL_MILES-The linear unit is nautical miles.

          * MILES-The linear unit is miles.

          * YARDS-The linear unit is yards.

          * FEET-The linear unit is feet.

          * INCHES-The linear unit is inches.

          * DECIMAL_DEGREES-The linear unit is decimal degrees.

          * POINTS-The linear unit is points.

          * UNKNOWN-The linear unit is unknown.

     OUTPUTS:
      out_obstacle_feature_class {Feature Layer}:
          The output point features that represent lidar points in OIS features
          in which the height of the lidar point is greater than the height of
          the enclosing OIS feature at that point. This feature class is
          required output only if no output LAS dataset is requested.
      target_folder {Folder}:
          The folder to which LAS files will be written. Each output file will
          have the same LAS file version and point record format as the input
          file. This folder is required output only if no output feature class
          is requested.
      out_las_obstacles {LAS Dataset Layer}:
          The output LAS dataset referencing the newly created LAS files. This
          LAS Dataset is created only when the output folder is specified to
          generate the LAS output."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AnalyzeLASRunwayObstacles_aviation(*gp_fixargs((in_ois_features, in_las_obstacles, out_obstacle_feature_class, target_folder, out_las_obstacles, vertical_clearance, vertical_clearance_unit), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AnalyzeRunwayObstacles_aviation', None)
def AnalyzeRunwayObstacles(input_ois_features=None, input_obstacle_features=None, out_feature_class=None, height_field=None, unit_field=None, height_option=None, elevation_option=None, elevation_field=None, elevation_field_unit=None, in_dems=None):
    """AnalyzeRunwayObstacles_aviation(input_ois_features, input_obstacle_features, out_feature_class, {height_field}, {unit_field}, {height_option}, {elevation_option}, {elevation_field}, {elevation_field_unit}, {in_dems;in_dems...})

        Analyzes obstacle data and obstruction identification surfaces (OIS)
        to determine if obstacles are penetrating.

     INPUTS:
      input_ois_features (Feature Layer):
          The multipatch features with defined Airport schema. The feature class
          must be z-enabled.
      input_obstacle_features (Feature Layer):
          The input obstacle features that will be analyzed. The feature class
          must be z-enabled.
      height_field {String}:
          The field containing the height of the obstacle features. The default
          value is Feature Geometry.

          * FEATURE_GEOMETRY-The field containing the height of the obstacle
          features.
      unit_field {String}:
          Specifies the linear unit of the obstacle height.

          * KILOMETERS-The linear unit is kilometers.

          * METERS-The linear unit is meters.

          * DECIMETERS-The linear unit is decimeters.

          * CENTIMETERS-The linear unit is centimeters.

          * MILLIMETERS-The linear unit is millimeters.

          * NAUTICAL_MILES-The linear unit is nautical miles.

          * MILES-The linear unit is miles.

          * YARDS-The linear unit is yards.

          * FEET-The linear unit is feet.

          * INCHES-The linear unit is inches.

          * DECIMAL_DEGREES-The linear unit is decimal degrees.

          * POINTS-The linear unit is points.

          * UNKNOWN-The linear unit is unknown.
      height_option {String}:
          Specifies how obstacle height values will be interpreted.

          * ABSOLUTE_HEIGHT-Obstacle heights are measured from sea level. This
          is the default.

          * RELATIVE_HEIGHT-Obstacle heights are measured from ground level.
      elevation_option {String}:
          Specifies how obstacle base elevation heights are identified. This
          parameter is enabled if the height_option parameter is set to
          RELATIVE_HEIGHT.

          * ELEVATION_FIELD-Base elevation heights are derived from a numeric
          field of the obstacle feature class. This is the default.

          * ELEVATION_DEM-Base elevation heights are derived from one or more
          DEMs.
      elevation_field {String}:
          The field containing base elevation heights of the obstacle
          features.This parameter is enabled if the height_option parameter is
          set to
          RELATIVE_HEIGHT and the elevation_option parameter is set to
          ELEVATION_FIELD. The default is the first numeric field in the
          obstacle feature class.
      elevation_field_unit {String}:
          Specifies the linear unit of the base elevation values. This parameter
          is enabled if the height_option parameter is set to RELATIVE_HEIGHT
          and the elevation_option parameter is set to ELEVATION_FIELD.

          * KILOMETERS-The linear unit is kilometers.

          * METERS-The linear unit is meters. This is the default.

          * DECIMETERS-The linear unit is decimeters.

          * CENTIMETERS-The linear unit is centimeters.

          * MILLIMETERS-The linear unit is millimeters.

          * NAUTICAL_MILES-The linear unit is nautical miles.

          * MILES-The linear unit is miles.

          * YARDS-The linear unit is yards.

          * FEET-The linear unit is feet.

          * INCHES-The linear unit is inches.

          * DECIMAL_DEGREES-The linear unit is decimal degrees.

          * POINTS-The linear unit is points.

          * UNKNOWN-The linear unit is unknown.
      in_dems {Raster Layer}:
          The DEMs covering the obstacles, used to derive base elevation values.
          This parameter is enabled if the height_option parameter is set to
          RELATIVE_HEIGHT and the elevation_option parameter is set to
          ELEVATION_DEM.

     OUTPUTS:
      out_feature_class (Feature Class):
          A feature class containing one point for each obstacle feature that
          falls within the area covered by the input OIS. If the geometry type
          of the input obstacle feature is a polyline or polygon, a multipoint
          feature class will be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AnalyzeRunwayObstacles_aviation(*gp_fixargs((input_ois_features, input_obstacle_features, out_feature_class, height_field, unit_field, height_option, elevation_option, elevation_field, elevation_field_unit, in_dems), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateOISObstacleData_aviation', None)
def GenerateOISObstacleData(in_runway_features=None, in_dems=None, in_obstacle_features=None, target_ois_features=None, obstacle_height_field=None, obstacle_height_unit=None, in_flightpath_features=None, label_field=None, height_option=None, elevation_option=None, elevation_field=None, elevation_field_unit=None):
    """GenerateOISObstacleData_aviation(in_runway_features, {in_dems;in_dems...}, in_obstacle_features, target_ois_features, {obstacle_height_field}, {obstacle_height_unit}, {in_flightpath_features}, {label_field}, {height_option}, {elevation_option}, {elevation_field}, {elevation_field_unit})

        Generates a JSON string that is stored in the OBSTACLEJSON field on
        the input Obstruction Identification Surface (OIS) multipatch feature
        class that contains the data necessary to depict obstacles to safety
        of flight within the approach surfaces (in the form of points, lines,
        or polygons) in the Terrain and Obstacle Profile layout element.For
        each runway feature, the tool identifies each of the approach
        surfaces associated with that runway. For each approach surface, the
        tool uses the underlying elevation models and input obstacle features
        to determine the highest elevations and heights of those obstacle
        features that intersect the approach surfaces extent. The resulting 3D
        points, representing the highest-point cross section of each affected
        obstacle, are created and stored in JSON format and saved in the
        corresponding approach OIS feature. The following table shows
        values that are populated in the
        OBSTACLEJSON output message. They are given per input obstacle feature
        if the planimetrically intersect any input approach surface multipatch
        feature. FieldExamplePopulated withType_Code"Type_Code":
        "Stack"Input Obstacle Features Type_Code field. It is given as the
        description for its coded domain value or as Unknown if no domain
        value is found or if the input is null.HACCM"HACCM": 0.304801Input
        Obstacle Features HORIZACC_VAL field, converted to meters. It is
        given as -1.0 if the input is null.VACCM"VACCM": 0.304801Input
        Obstacle Features VERTACC_VAL field, converted to meters. It is
        given as -1.0 if the input is null.Height"Height": 16.664848Value of
        Input Obstacle Height parameter (feature geometry or input
        field) converted to meters.GNDElev"GNDElev": 335.647491The ground
        elevation at the Input Obstacle's location from Elevation
        Source (DEM or input field) converted to
        meters.NormalDist"NormalDist": 946.035675The distance, in meters,
        between the obstacle and the nearest point on
        the runway centerline.Offset"Offset": 143.128218The distance, in
        meters, between the obstacle and the nearest point on
        the extended runway centerline.X"X": -95.953753The x-coordinate of the
        obstacle in WGS84 decimal degrees.Y"Y": 45.550517The y-coordinate of
        the obstacle in WGS84 decimal degrees.ZVMC"ZVMC": 352.31234The
        elevation of the top of the obstacle (Height + GNDElev) in
        meters.OIS"OIS": 384.942139The z-value of the OIS at the obstacle's
        location.Penetrates"Penetrates": falseA value of true if ZVMC is
        greater than or equal to OIS; otherwise,
        false.Label"Label": "362"The value of the Obstacle Labels input
        parameter.

     INPUTS:
      in_runway_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      in_dems {Raster Layer}:
          The DEMs covering the obstacles, used to derive base elevation values.
          This parameter is used if elevation_option is set to ELEVATION_DEM.
      in_obstacle_features (Feature Layer):
          The input obstacle features that will be analyzed. The feature class
          must be z-enabled.
      target_ois_features (Feature Layer):
          The multipatch features with defined airport data model schema. The
          feature class must be z-enabled.
      obstacle_height_field {String}:
          The field containing the height of the obstacle features or the
          keyword FEATURE_GEOMETRY to indicate obstacle feature geometry
          z-coordinate values.

          * FEATURE_GEOMETRY-The field containing the height of the obstacle
          features.
      obstacle_height_unit {String}:
          Specifies the obstacle height unit of measure.

          * KILOMETERS-The unit is kilometers.

          * METERS-The unit is meters.

          * DECIMETERS-The unit is decimeters.

          * CENTIMETERS-The unit is centimeters.

          * MILLIMETERS-The unit is millimeters.

          * NAUTICAL_MILES-The unit is nautical miles.

          * MILES-The unit is miles.

          * YARDS-The unit is yards.

          * FEET-The unit is feet.

          * INCHES-The unit is inches

          * DECIMAL_DEGREES-The unit is decimal degrees.

          * POINTS-The unit is points.

          * UNKNOWN-The unit is unknown.
      in_flightpath_features {Feature Layer}:
          The polyline features that define curved approaches to the specified
          runways. If unspecified, all input features will be processed as
          straight approaches.
      label_field {String}:
          A field from the input obstacle feature class. When an obstacle JSON
          generated by this tool is later used to create a Terrain and Obstacle
          Profile element in a layout, the data from the selected field will be
          used to label the input point obstacles in that element. The
          Obstacle Labels parameter only applies to Input Obstacle
          Features parameter values that contain point features. If no
          value is specified, the ObjectID will be applied by default.
      height_option {String}:
          Specifies how the tool interprets obstacle height values.

          * ABSOLUTE_HEIGHT-Obstacle heights are measured from sea level.

          * RELATIVE_HEIGHT-Obstacle heights are measured from ground level.
          This is the default.
      elevation_option {String}:
          Specifies where the tool finds the obstacle base elevation heights.

          * ELEVATION_FIELD-Base elevation heights will be found in a numeric
          field of the obstacle feature class.

          * ELEVATION_DEM-Base elevation heights will be found by deriving them
          from one or more DEMs. This is the default.
      elevation_field {String}:
          The field containing base elevation heights of the obstacle
          features.This parameter is used if elevation_option is set to
          ELEVATION_FIELD.
          The default is the first numeric field in the obstacle feature class.
      elevation_field_unit {String}:
          Specifies the linear unit of the base elevation values. This parameter
          is used if elevation_option is set to ELEVATION_FIELD.

          * KILOMETERS-The unit is kilometers.

          * METERS-The unit is meters. This is the default.

          * DECIMETERS-The unit is decimeters.

          * CENTIMETERS-The unit is centimeters.

          * MILLIMETERS-The unit is millimeters.

          * NAUTICAL_MILES-The unit is nautical miles.

          * MILES-The unit is miles.

          * YARDS-The unit is yards.

          * FEET-The unit is feet.

          * INCHES-The unit is inches

          * DECIMAL_DEGREES-The unit is decimal degrees.

          * POINTS-The unit is points.

          * UNKNOWN-The unit is unknown."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateOISObstacleData_aviation(*gp_fixargs((in_runway_features, in_dems, in_obstacle_features, target_ois_features, obstacle_height_field, obstacle_height_unit, in_flightpath_features, label_field, height_option, elevation_option, elevation_field, elevation_field_unit), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateOISProfileData_aviation', None)
def GenerateOISProfileData(in_runway_features=None, in_dems=None, target_ois_features=None, in_flightpath_features=None, sampling_distance=None, sample_profile_ois=None, sample_profile_runways=None):
    """GenerateOISProfileData_aviation(in_runway_features, in_dems;in_dems..., target_ois_features, {in_flightpath_features}, {sampling_distance}, {sample_profile_ois}, {sample_profile_runways})

        Generates a JSON string that is stored in the PROFILEJSON field on the
        input Obstruction Identification Surface multipatch feature class that
        contains the data necessary to depict the terrain, runway, and OIS in
        the Terrain and Obstacle Profile layout element.For each runway
        feature, the tool finds each of the approach surfaces
        associated with that runway. With each approach surface, the tool uses
        the sampling distance parameter to extend from the runway and collect
        the centerline, the highest and lowest values for the terrain along a
        parallel extending from edge to edge. It also collects the profile
        information for the runway and the approach surface. The resulting 3D
        points representing the terrain, runway, and approach surface are
        stored in JSON format and saved in the corresponding approach OIS
        feature.The output JSON string in PROFILEJSON will include elements
        defining
        the RunwayCenterline, OIS, Terrain, and OIS edges sections. All
        coordinates are in WGS84, and elevations and distances are given in
        meters. The following table describes the values stored in the
        element
        paths data within each element:     Element pathsExamplePopulated
        withRunwayCenterline[-95.9594, 45.5582, 336.6764,
        30.0]RunwayCenterline point coordinates and elevation at input
        sampling
        distance interval [Longitude, Latitude, Elevation, Distance from
        nearest Runway End]OIS[-95.9587, 45.5575, 342.1426, 90.0]Obstruction
        Identification Surface coordinates and altitude at input
        sampling distance interval [Longitude, Latitude, Elevation, Distance
        from nearest Runway End]Terrain[-95.9592, 45.5579, 338.3926, 338.3926,
        338.3926, 30.0]Terrain coordinates and elevations across OIS extent at
        input sampling
        distance interval [Longitude, Latitude, Minimum Elevation, Elevation
        along extended runway, Maximum Elevation, Distance from nearest Runway
        End]Edges[-95.958, 45.5578, -95.9594, 45.5572, 90.0]Coordinates of OIS
        edges at opposite sides, outward from runway end at
        input sampling distance interval [Side 1 Longitude, Side 1 Latitude,
        Side 2 Longitude, Side 2 Latitude, Distance from nearest Runway End]

     INPUTS:
      in_runway_features (Feature Layer):
          This is the input runway dataset. The feature class must be z-enabled
          and contain polylines.
      in_dems (Raster Layer):
          The DEMs covering the runways and their approach obstruction
          identification surfaces.
      target_ois_features (Feature Layer):
          The multipatch features with defined Airport schema. The feature class
          must be z-enabled.
      in_flightpath_features {Feature Layer}:
          The polyline features that define curved approaches to the specified
          runways. If unspecified, all input features will be processed as
          straight approaches.
      sampling_distance {Double}:
          The distance, in meters, between generated points. The default is 30.
      sample_profile_ois {Boolean}:
          Specifies whether elevation points for OIS features will be generated.

          * PROFILE_OIS-Generates elevation points.

          * NO_PROFILE_OIS-Elevation points will not be generated. This is
          default.
      sample_profile_runways {Boolean}:
          Specifies whether elevation points along the runways will be
          generated.

          * PROFILE_RUNWAY-Generates elevation points along the runways.

          * NO_PROFILE_RUNWAY-Uses only the start and end points of the runways.
          This is default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateOISProfileData_aviation(*gp_fixargs((in_runway_features, in_dems, target_ois_features, in_flightpath_features, sampling_distance, sample_profile_ois, sample_profile_runways), True)))
        return retval
    except Exception as e:
        raise e


# Airports\Data Exchange toolset
@gptooldoc('ExportFAA18BShapefiles_aviation', None)
def ExportFAA18BShapefiles(in_workspace=None, target_folder=None, in_features=None):
    """ExportFAA18BShapefiles_aviation(in_workspace, target_folder, {in_features;in_features...})

        Exports one or more FAA Advisory Circular 150/5300-18B compliant
        shapefiles from a geodatabase that contains the ArcGIS Aviation
        Airports schema.

     INPUTS:
      in_workspace (Workspace):
          The workspace that contains the airport data.
      target_folder (Folder):
          The folder to which shapefiles are written.
      in_features {String}:
          A list of feature classes to export to shapefiles. If this parameter
          is not set, all feature classes in the input workspace are exported to
          shapefiles."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportFAA18BShapefiles_aviation(*gp_fixargs((in_workspace, target_folder, in_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportFAA18BShapefiles_aviation', None)
def ImportFAA18BShapefiles(in_features=None, airports_workspace=None):
    """ImportFAA18BShapefiles_aviation(in_features;in_features..., airports_workspace)

        Imports one or more FAA Advisory Circular 150/5300-18B compliant
        shapefiles into a geodatabase that contains the ArcGIS Aviation
        Airports schema.

     INPUTS:
      in_features (Shapefile):
          The FAA 18B shapefiles to be imported into a geodatabase.
      airports_workspace (Workspace):
          The geodatabase into which the shapefiles will be imported."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportFAA18BShapefiles_aviation(*gp_fixargs((in_features, airports_workspace), True)))
        return retval
    except Exception as e:
        raise e


# Airports\Heliport Obstruction Identification Surfaces toolset
@gptooldoc('FAA2C_aviation', None)
def FAA2C(input_fato_features=None, target_ois_features=None, surface_classification=None, surface_shape=None, approach_bearing=None, in_flightpath_features=None, helipad_elevation=None, custom_json_file=None):
    """FAA2C_aviation(input_fato_features, target_ois_features, surface_classification, {surface_shape}, {approach_bearing}, {in_flightpath_features}, {helipad_elevation}, {custom_json_file})

        Generates an Obstruction Identification Surface (OIS) for helipads
        based on specifications from FAA Advisory Circular 150/5390-2C.This
        tool can be used to identify obstacles that may impact an
        aircraft's ability to take off from or land on a helipad. By creating
        multipatch or polygon features, you can visually identify obstructions
        in ArcGIS Pro.

     INPUTS:
      input_fato_features (Feature Layer):
          The input Final Approach and Takeoff (FATO) features.
      target_ois_features (Feature Layer):
          The target polygon or multipatch feature layer containing the
          Obstruction Identification Surfaces (OIS).
      surface_classification (String):
          Specifies the classification type of the Final Approach and Takeoff
          (FATO) surface.

          * NON_PRIOR_PERMISSION_REQUIRED_FACILITIES-Publically available
          helipads for general use by pilots. This is the default.

          * PRIOR_PERMISSION_REQUIRED_FACILITIES-A heliport used exclusively by
          the owner and individuals authorized by the owner to use the facility.
      surface_shape {String}:
          Specifies the shape of the take off or approach surface.

          * STRAIGHT_SURFACE-The take off or approach surface is straight. This
          is the default.

          * CURVED_SURFACE-The take off or approach surface is curved.
      approach_bearing {Double}:
          The absolute bearing that an approaching aircraft will travel along
          the surface. A value of 0 will align the surface to true north. The
          default value is 0.
      in_flightpath_features {Feature Layer}:
          The polyline flight path features that the curved surface will follow.
      helipad_elevation {Double}:
          The elevation of the highest point of the helipad. The value must be
          in the vertical coordinate system linear units of the target feature
          class. If no value is provided, the highest point of the
          input_fato_features parameter value will be used. The default value is
          0.
      custom_json_file {File}:
          The import configuration file, in JSON format, that creates the custom
          OIS."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FAA2C_aviation(*gp_fixargs((input_fato_features, target_ois_features, surface_classification, surface_shape, approach_bearing, in_flightpath_features, helipad_elevation, custom_json_file), True)))
        return retval
    except Exception as e:
        raise e


# Airports\Obstruction Identification Surfaces toolset
@gptooldoc('CreateCurvedApproach_aviation', None)
def CreateCurvedApproach(in_runway_features=None, in_flightpath_features=None, target_ois_features=None, specification=None, runway_classification=None, custom_json_file=None, threshold_offset=None):
    """CreateCurvedApproach_aviation(in_runway_features, in_flightpath_features, target_ois_features, specification, runway_classification, {custom_json_file}, {threshold_offset})

        Creates curved approach obstacle identification surfaces (OIS) based
        on the supported specifications in ArcGIS Aviation. These curved
        approach surfaces are based on an input flight path and the
        information in the selected specification, for example, ICAO Annex 15,
        FAA 18B and classification. This tool creates surfaces in existing
        polygon or multipatch features.

     INPUTS:
      in_runway_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      in_flightpath_features (Feature Layer):
          The polyline features that define curved approaches to the specified
          runways.
      target_ois_features (Feature Layer):
          The target feature class that will contain the generated OIS.
      specification (String):
          Specifies the approach surface specification.

          * ETOD-ICAO Annex 15 (ETOD)

          * OLS-ICAO Annex 14 (OLS)

          * FAR77-FAA regulations part 77 (FAR77)

          * 18B-FAA Advisory circular 150/5300_18B (18B)

          * 13A-FAA Advisory circular 150/5300_13A (13A)
      runway_classification (String):
          The runway classification of the approach surface.The option used for
          the Specification parameter (specification in
          Python) will determine the available options for the this parameter.
      custom_json_file {File}:
          The import configuration, in JSON format, that creates the custom OIS.
      threshold_offset {Double}:
          The distance offset from the runway end point. The threshold will be
          applied in the units of the input."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateCurvedApproach_aviation(*gp_fixargs((in_runway_features, in_flightpath_features, target_ois_features, specification, runway_classification, custom_json_file, threshold_offset), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FAA13A_aviation', None)
def FAA13A(in_features=None, target=None, runway_type=None, highend_clear_way_length=None, lowend_clear_way_length=None, custom_json_file=None, generate_clearway_surface=None, airport_control_point_feature_class=None):
    """FAA13A_aviation(in_features, target, runway_type, {highend_clear_way_length}, {lowend_clear_way_length}, {custom_json_file}, {generate_clearway_surface}, {airport_control_point_feature_class})

        Creates obstruction identification surfaces (OIS) based on the FAA
        Advisory Circular 150/5300-13A specification. These approach and
        departure surfaces are designed to protect the use of the runway in
        both visual and instrument meteorological conditions near the airport
        and are used to support planning and design activities. The type,
        function, and dimension of a surface differ by its runway
        classification. This tool creates surfaces as a polygon or multipatch
        features.

     INPUTS:
      in_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      target (Feature Layer):
          The target feature class that will contain the generated OIS.
      runway_type (String):
          Specifies the classification of the runway.

          * SMALL_AIRPLANE_APPROACH_SPEEDS_LT_50-Approach end of runways are
          expected to serve small airplanes with approach speeds less than 50
          knots. This applies to visual runways only, day or night.

          * SMALL_AIRPLANE_APPROACH_SPEEDS_GT_50-Approach end of runways are
          expected to serve small airplanes with approach speeds of 50 knots or
          more. This applies to visual runways only, day or night.

          * LARGE_AIRPLANE_VISUAL_RUNWAY_DAY_NIGHT-Approach end of runway are
          expected to serve large airplanes. This applies to visual runways
          only, day or night.

          * INSTRUMENT_GT_EQ_3/4_MILE-Approach end of runways are expected to
          accommodate instrument approaches having visibility greater than or
          equal to 3/4 statute mile.

          * INSTRUMENT_LT_3/4_MILE_VISIBILITY-Approach end of runways are
          expected to accommodate instrument approaches having visibility
          minimums less than 3/4 statute mile.

          * VERTICAL_GUIDANCE_APPROACH-Approach end of runways are expected to
          accommodate instrument approaches with vertical guidance.

          * DEPARTURE-Departure runway ends are used for any instrument
          operations.
      highend_clear_way_length {Double}:
          This parameter is no longer supported. It is still included in the
          tool's syntax for compatibility in scripts and models but is hidden on
          the tool dialog box.
      lowend_clear_way_length {Double}:
          This parameter is no longer supported. It is still included in the
          tool's syntax for compatibility in scripts and models but is hidden on
          the tool dialog box.
      custom_json_file {File}:
          The import configuration, in JSON format, that creates the custom OIS.
      generate_clearway_surface {Boolean}:
          Specifies whether a clearway surface will be generated for departure
          runways.

          * GENERATE_CLEARWAY_SURFACE-A clearway surface will be generated.

          * NOT_GENERATE_CLEARWAY_SURFACE-A clearway surface will not be
          generated. This is the default.
      airport_control_point_feature_class {Feature Layer}:
          Supplies x-, y-, and z-geometry for displaced threshold features. If
          displaced thresholds are included, surfaces will be constructed based
          on their x-, y-, and z-geometry instead of their corresponding runway
          feature endpoint."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FAA13A_aviation(*gp_fixargs((in_features, target, runway_type, highend_clear_way_length, lowend_clear_way_length, custom_json_file, generate_clearway_surface, airport_control_point_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FAA18B_aviation', None)
def FAA18B(in_features=None, target=None, runway_type=None, highend_clear_way_length=None, lowend_clear_way_length=None, airport_elevation=None, include_merged_surface=None, custom_json_file=None, airport_control_point_feature_class=None):
    """FAA18B_aviation(in_features, target, runway_type, {highend_clear_way_length}, {lowend_clear_way_length}, {airport_elevation}, {include_merged_surface}, {custom_json_file}, {airport_control_point_feature_class})

        Creates obstruction identification surfaces (OIS) based on the FAA
        Advisory Circular 150/5300-18B specification. These OIS assist in the
        identification of possible hazards to air navigation and critical
        approach/departure obstructions within the vicinity of the airport and
        are used to support planning and design activities. The type,
        function, and dimension of a surface differ by its runway
        classification. This tool creates surfaces such as a polygon or
        multipatch features

     INPUTS:
      in_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      target (Feature Layer):
          The target feature class that will contain the generated obstruction
          identification surfaces.
      runway_type (String):
          Specifies the runway classification of in_features.

          * NON_VERTICAL_GUIDANCE_TYPE_1-A runway designed for visual maneuvers,
          nonvertically guided operations, and instrument departure procedures.

          * NON_VERTICAL_GUIDANCE_TYPE_2-A specially prepared hard surface
          (SPHS) runway designed for visual maneuvers, nonvertically guided
          operations, and instrument departure procedures. SPHS runways have a
          primary surface that extends 200 feet beyond each end of the runway.

          * VERTICAL_GUIDANCE-A runway that uses precision guidance systems to
          support aircraft approach and landing.
      highend_clear_way_length {Double}:
          The length of the area at the high end of the runway. The unit of
          measurement is based on the input runway features.
      lowend_clear_way_length {Double}:
          The length of the area at the low end of the runway. The unit of
          measurement is based on the input runway features.
      airport_elevation {Double}:
          The highest elevation on any of the runways of the airport. The value
          should be given in the vertical coordinate system linear units of the
          target feature class. If no value is given, the highest point on the
          Input Runway Features will be used.
      include_merged_surface {Boolean}:
          Indicates whether merged horizontal and conical surfaces are included
          in the OIS in addition to the regular surfaces.

          * INCLUDE_MERGED_SURFACE-Include merged surfaces in the OIS output.
          This is the default.

          * NOT_INCLUDE_MERGED_SURFACE-Do not include merged surfaces in the
          OIS output.
      custom_json_file {File}:
          The import configuration, in JSON format, that creates the custom OIS.
      airport_control_point_feature_class {Feature Layer}:
          The point features containing an Airport Elevation feature, displaced
          threshold features, or both. Values provided in the Airport Elevation
          parameter will take precedence over these point features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FAA18B_aviation(*gp_fixargs((in_features, target, runway_type, highend_clear_way_length, lowend_clear_way_length, airport_elevation, include_merged_surface, custom_json_file, airport_control_point_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FAAFAR77_aviation', None)
def FAAFAR77(in_features=None, target=None, high_runway_end_type=None, low_runway_end_type=None, specially_prepared_hard_surface_runway=None, highend_clear_way_length=None, lowend_clear_way_length=None, airport_elevation=None, include_merged_surface=None, custom_json_file=None, airport_control_point_feature_class=None):
    """FAAFAR77_aviation(in_features, target, high_runway_end_type, low_runway_end_type, {specially_prepared_hard_surface_runway}, {highend_clear_way_length}, {lowend_clear_way_length}, {airport_elevation}, {include_merged_surface}, {custom_json_file}, {airport_control_point_feature_class})

        Creates obstruction identification surfaces (OIS) based on the FAA
        Part 77 specification. This regulation establishes standards and
        notification requirements for objects affecting navigable airspace.
        The type, function, and dimension of a surface differ by its runway
        classification. This tool creates surfaces as a polygon or multipatch
        features.

     INPUTS:
      in_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      target (Feature Layer):
          The target feature class that will contain the generated obstruction
          identification surfaces.
      high_runway_end_type (String):
          Specifies the classification of the high end of the runway.

          * CONSTRUCTION_OR_ALTERATION_ON_AN_AIRPORT_WITH_LONGEST_RUNWAY_MORE_TH
          AN_3200_FEET-Construction on or alteration to a runway longer than
          3,200 feet with an imaginary surface that extends outward 20,000 feet
          and has a slope that does not exceed 100 to 1.

          * CONSTRUCTION_OR_ALTERATION_ON_AN_AIRPORT_WITH_LONGEST_RUNWAY_LESS_TH
          AN_3200_FEET-Construction on or alteration to a runway less than 3,200
          feet long with an imaginary surface that extends outward 10,000 feet
          and has a slope that does not exceed 50 to 1.

          * CONSTRUCTION_OR_ALTERATION_ON_A_HELIPORT-Construction on or
          alteration to a heliport landing and takeoff area with an imaginary
          surface that extends outward 5,000 feet and has a slope that does not
          exceed 25 to 1.

          * MILITARY_AIRPORT-Military airport runways are operated by an armed
          force of the United States. Primary surfaces are the same length as
          the runway. Primary surface width is 2,000 feet. Clear zone surface
          length is 1,000 feet, and width is the same as the primary surface.
          The approach clearance surface starts 200 feet beyond each end of the
          primary surface and extends for 50,000 feet. Approach surface width
          matches the primary surface width at the runway end but flares to a
          width of 16,000 feet at an elevation of 50,000 feet. Approach
          clearance surface slope is 50 to 1 to an elevation of 500 feet above
          airport elevation. It then rises horizontally to 50,000 feet.
          Transitional surface slope is 7 to 1 outward and upward at right
          angles to the runway centerline. See section 77.28 in the FAR Part 77
          specification for more information.

          *
          NONPRECISION_INSTRUMENT_RUNWAY_GREATER_THAN_(>)_3/4_MILE_VISIBILITY-A
          runway with a nonprecision instrument approach procedure that allows
          for landing in visibility conditions greater than three-quarters of a
          mile.

          * NONPRECISION_INSTRUMENT_RUNWAY_LESS_THAN_(<)_3/4_MILE_VISIBILITY-A
          runway with a nonprecision instrument approach procedure that allows
          for landing in visibility conditions less than three-quarters of a
          mile.

          * PRECISION_INSTRUMENT_RUNWAY-A runway that uses Instrument Landing
          System (ILS) or Precision Approach Radar (PAR) for approach
          procedures.

          * UTILITY_RUNWAY_VISUAL_APPROACH-A runway built for propeller aircraft
          not exceeding 12,500 pounds gross weight. Aircraft using the runway
          employ visual approach procedures.

          * UTILITY_RUNWAY_NON_PRECISION_INSTRUMENT_APPROACH-A runway built for
          propeller aircraft not exceeding 12,500 pounds gross weight. The
          runway has an instrument approach procedure that uses air navigation
          facilities with horizontal guidance. It can also have area-type
          navigation equipment with approved nonprecision instrument approach
          procedures.

          * VISUAL_RUNWAY_VISUAL_APPROACH-A runway that supports only visual
          approach procedures.
      low_runway_end_type (String):
          Specifies the classification of the low end of the runway.

          * SAME_AS_HIGH_RUNWAY_END_CLASSIFICATION-No low runway end type.

          *
          NONPRECISION_INSTRUMENT_RUNWAY_GREATER_THAN_(>)_3/4_MILE_VISIBILITY-A
          runway with a nonprecision instrument approach procedure that allows
          for landing in visibility conditions greater than three-quarters of a
          mile.

          * NONPRECISION_INSTRUMENT_RUNWAY_LESS_THAN_(<)_3/4_MILE_VISIBILITY-A
          runway with a nonprecision instrument approach procedure that allows
          for landing in visibility conditions less than three-quarters of a
          mile.

          * PRECISION_INSTRUMENT_RUNWAY-A runway that uses Instrument Landing
          System (ILS) or Precision Approach Radar (PAR) for approach
          procedures.

          * UTILITY_RUNWAY_VISUAL_APPROACH-A runway built for propeller aircraft
          not exceeding 12,500 pounds gross weight. Aircraft using the runway
          employ visual approach procedures.

          * UTILITY_RUNWAY_NON_PRECISION_INSTRUMENT_APPROACH-A runway built for
          propeller aircraft not exceeding 12,500 pounds gross weight. The
          runway has an instrument approach procedure that uses air navigation
          facilities with horizontal guidance. It can also have area-type
          navigation equipment with approved nonprecision instrument approach
          procedures.

          * VISUAL_RUNWAY_VISUAL_APPROACH-A runway that supports only visual
          approach procedures.
      specially_prepared_hard_surface_runway {Boolean}:
          Specifies whether the runway has a specially prepared hard surface. A
          specially prepared hard surface indicates that the primary surface
          extends 200 feet beyond each end of the runway.

          * SPECIALLY_PREPARED_HARD_SURFACE_RUNWAY-The runway has a specially
          prepared hard surface. This is the default.

          * NON_SPECIALLY_PREPARED_HARD_SURFACE_RUNWAY-The runway does not have
          a specially prepared hard surface.
      highend_clear_way_length {Double}:
          The length of the area at the high end of the runway. The unit of
          measurement is based on the input runway features.
      lowend_clear_way_length {Double}:
          The length of the area at the low end of the runway. The unit of
          measurement is based on the input runway features.
      airport_elevation {Double}:
          The highest elevation on any of the runways of the airport. The value
          should be in the vertical coordinate system linear units of the target
          feature class. If no value is provided, the highest point from the
          Input Runway Features parameter value will be used.
      include_merged_surface {Boolean}:
          Specifies whether merged horizontal and conical surfaces are included
          in the OIS in addition to the regular surfaces.

          * INCLUDE_MERGED_SURFACE-Merged surfaces are included in the OIS
          output. This is the default.

          * NOT_INCLUDE_MERGED_SURFACE-Merged surfaces are not included in the
          OIS output.
      custom_json_file {File}:
          The import configuration, in JSON format, that creates the custom OIS.
      airport_control_point_feature_class {Feature Layer}:
          The point features containing an Airport Elevation feature, displaced
          threshold features, or both. Values provided in the Airport Elevation
          parameter will take precedence over these point features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FAAFAR77_aviation(*gp_fixargs((in_features, target, high_runway_end_type, low_runway_end_type, specially_prepared_hard_surface_runway, highend_clear_way_length, lowend_clear_way_length, airport_elevation, include_merged_surface, custom_json_file, airport_control_point_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateOISIntersection_aviation', None)
def GenerateOISIntersection(in_ois_features=None, out_ois_features=None, multipart_feature=None):
    """GenerateOISIntersection_aviation(in_ois_features;in_ois_features..., out_ois_features, {multipart_feature})

        Creates the most restrictive (lowest) surfaces within the extent of
        all collective surfaces. Obstruction identification surfaces (OIS)
        determine which objects are vertical obstructions. An object is
        considered a vertical obstruction if it penetrates the OIS surface.
        Surfaces are used to support planning and design activities.Many
        airports have more than one runway and each runway has a set of
        obstruction identification surfaces. Supporting automatic generation
        of new subsurfaces that constitute the overlapping portions of
        surfaces can have a better visualization and a more accurate analysis
        for an airport. To generate a single set of surfaces, multiple sets of
        surfaces are needed. This tool creates surfaces as multipatch
        features.

     INPUTS:
      in_ois_features (Feature Layer):
          The input OIS features. The feature class must be multipatch.
      multipart_feature {Boolean}:
          Specifies whether multipart features will be created in the output.
          Multipart features are composed of more than one physical part that
          only references one set of attributes.

          * MULTIPART-Multipart features will be created. This is default.

          * MERGE_ADJACENT-Adjacent triangulated multipart features will be
          created as individual features.

     OUTPUTS:
      out_ois_features (Feature Layer):
          The updated feature class containing the meshed OIS with the lowest
          z-value."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateOISIntersection_aviation(*gp_fixargs((in_ois_features, out_ois_features, multipart_feature), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ICAOAnnex14_aviation', None)
def ICAOAnnex14(in_features=None, target=None, runway_type=None, highend_clear_way_length=None, lowend_clear_way_length=None, airport_elevation=None, runway_direction=None, include_merged_surface=None, custom_json_file=None, airport_control_point_feature_class=None):
    """ICAOAnnex14_aviation(in_features, target, runway_type, {highend_clear_way_length}, {lowend_clear_way_length}, {airport_elevation}, {runway_direction}, {include_merged_surface}, {custom_json_file}, {airport_control_point_feature_class})

        Creates obstruction identification surfaces (OIS) based on the ICAO
        Annex 14 specification. These surfaces define the airspace around
        aerodromes to be free of obstacles so operations can be performed
        safely. This tool creates surfaces as a polygon or multipatch
        features.

     INPUTS:
      in_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      target (Feature Layer):
          The output feature class that will contain the generated obstruction
          identification surfaces.
      runway_type (String):
          Specifies the runway classification of the in_features parameter.

          * NON_INSTRUMENT_CODE_NUMBER_1-A runway intended for the operation of
          aircraft using visual approach procedures. Runway strip length is 30
          meters.

          * NON_INSTRUMENT_CODE_NUMBER_2-A runway with a 60-meter strip length
          and 40-meter strip width that is intended for the operation of
          aircraft using visual approach procedures.

          * NON_INSTRUMENT_CODE_NUMBER_3-A runway with a 60-meter strip length
          and 75-meter strip width that is intended for the operation of
          aircraft using visual approach procedures.

          * NON_INSTRUMENT_CODE_NUMBER_4-A runway with a 60-meter strip length
          and 75-meter strip width that is intended for the operation of
          aircraft using visual approach procedures.

          * NON_PRECISION_APPROACH_CODE_NUMBER_1-An instrument runway served by
          visual aids and a nonvisual aid providing at least directional
          guidance adequate for a straight-in approach. This runway type has a
          60-meter strip length and a 75-meter strip width on either side of the
          runway centerline.

          * NON_PRECISION_APPROACH_CODE_NUMBER_2-An instrument runway served by
          visual aids and a nonvisual aid providing at least directional
          guidance adequate for a straight-in approach. This runway type has a
          60-meter strip length and a 75-meter strip width on either side of the
          runway centerline.

          * NON_PRECISION_APPROACH_CODE_NUMBER_3-An instrument runway served by
          visual aids and a nonvisual aid providing at least directional
          guidance adequate for a straight-in approach. This runway type has a
          60-meter strip length and a 150-meter strip width on either side of
          the runway centerline.

          * NON_PRECISION_APPROACH_CODE_NUMBER_4-An instrument runway served by
          visual aids and a nonvisual aid providing at least directional
          guidance adequate for a straight-in approach. This runway type has a
          60-meter strip length and a 150-meter strip width on either side of
          the runway centerline.

          * PRECISION_APPROACH_CATEGORY_I_CODE_NUMBER_1-An instrument runway
          served by an Instrument Landing System (ILS) or a Microwave Landing
          System (MLS) and visual aids intended for operations with a decision
          height not lower than 60 meters (200 feet) and either a visibility not
          less than 800 meters or a runway visual range not less than 550
          meters. This runway type has a 60-meter strip length and a 75-meter
          strip width on either side of the runway centerline.

          * PRECISION_APPROACH_CATEGORY_I_CODE_NUMBER_2-An instrument runway
          served by ILS and/or MLS and visual aids intended for operations with
          a decision height not lower than 60 meters (200 feet) and either a
          visibility not less than 800 meters or a runway visual range not less
          than 550 meters. This runway type has a 60-meter strip length and a
          75-meter strip width on either side of the runway centerline.

          * PRECISION_APPROACH_CATEGORY_I_CODE_NUMBER_3_4-An instrument runway
          served by ILS and/or MLS and visual aids intended for operations with
          a decision height not lower than 60 meters (200 feet) and either a
          visibility not less than 800 meters or a runway visual range not less
          than 550 meters. This runway type has a 60-meter strip length and a
          150-meter strip width on either side of the runway centerline.

          * PRECISION_APPROACH_CATEGORY_II_III_CODE NUMBER_3_4-An instrument
          runway served by ILS and/or MLS and visual aids intended for
          operations with a decision height lower than 60 meters (200 feet) but
          not lower than 30 meters (100 feet) and a runway visual range not less
          than 350 meters. This runway type has a 60-meter strip length and a
          150-meter strip width on either side of the runway centerline.
      highend_clear_way_length {Double}:
          The length of the area at the high end of the runway. The unit of
          measurement is based on the input runway features.
      lowend_clear_way_length {Double}:
          The length of the area at the low end of the runway. The unit of
          measurement is based on the input runway features.
      airport_elevation {Double}:
          The highest elevation on any of the runways of the airport. The value
          should be given in the vertical coordinate system linear units of the
          target feature class. If no value is given, the highest point of the
          Input Runway Features will be used.
      runway_direction {String}:
          Specifies at which end of the runway the approach surface will be
          created.

          * HIGH_END_TO_LOW_END-From runway high end to low end. The approach
          surface will be created at the high end of the runway. If a displaced
          threshold point exists at the high end of the runway, that point will
          be honored when creating the OIS.

          * LOW_END_TO_HIGH_END-From runway low end to high end. The approach
          surface will be created at the low end of the runway. If a displaced
          threshold point exists at the low end of the runway, that point will
          be honored when creating the OIS.
      include_merged_surface {Boolean}:
          Specifies whether merged surfaces will be generated.

          * INCLUDE_MERGED_SURFACE-All the surfaces will be generated for the
          merged surfaces, as well as merged conical and horizontal surfaces.
          This is the default.

          * NOT_INCLUDE_MERGED_SURFACE-Surfaces will not be generated for the
          merged surfaces.
      custom_json_file {File}:
          The import configuration, in JSON format, that creates the custom OIS.
      airport_control_point_feature_class {Feature Layer}:
          The point features containing an Airport Elevation feature, displaced
          threshold features, or both. Values provided in the Airport Elevation
          parameter will take precedence over these point features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ICAOAnnex14_aviation(*gp_fixargs((in_features, target, runway_type, highend_clear_way_length, lowend_clear_way_length, airport_elevation, runway_direction, include_merged_surface, custom_json_file, airport_control_point_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ICAOAnnex15_aviation', None)
def ICAOAnnex15(in_features=None, target=None, highend_clear_way_length=None, lowend_clear_way_length=None, custom_json_file=None, airport_control_point_feature_class=None):
    """ICAOAnnex15_aviation(in_features, target, {highend_clear_way_length}, {lowend_clear_way_length}, {custom_json_file}, {airport_control_point_feature_class})

        Creates obstruction identification surfaces (OIS) based on the ICAO
        Annex 15 specification (Areas 2a, 2b, and 2c). These surfaces assist
        in determining the height restriction or removal of obstacles that
        pose a hazard to air navigation in and around an aerodrome. This tool
        creates surfaces as a polygon or multipatch features.

     INPUTS:
      in_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      target (Feature Layer):
          The target feature class that will contain the generated obstruction
          identification surfaces.
      highend_clear_way_length {Double}:
          The length of the area at the high end of the runway. The unit of
          measurement is based on the input runway features.
      lowend_clear_way_length {Double}:
          The length of the area at the low end of the runway. The unit of
          measurement is based on the input runway features.
      custom_json_file {File}:
          The import configuration, in JSON format, that creates the custom OIS.
      airport_control_point_feature_class {Feature Layer}:
          Supplies x-, y-, and z-geometry for displaced threshold features. If
          displaced thresholds are included, surfaces will be constructed based
          on their x-, y-, and z-geometry instead of their corresponding runway
          feature endpoint."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ICAOAnnex15_aviation(*gp_fixargs((in_features, target, highend_clear_way_length, lowend_clear_way_length, custom_json_file, airport_control_point_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ICAOAnnex4_aviation', None)
def ICAOAnnex4(in_features=None, target=None, runway_direction=None, length=None, width=None, slope=None, height=None, airport_control_point_feature_class=None):
    """ICAOAnnex4_aviation(in_features, target, {runway_direction}, {length}, {width}, {slope}, {height}, {airport_control_point_feature_class})

        Creates obstruction identification surfaces (OIS) based on the ICAO
        Annex 4 specification for the Precision Approach Terrain chart.These
        surfaces are designed to aid in the analysis of the terrain and
        features within a defined portion of the final approach that is
        depicted on the Precision Approach Terrain chart type. To generate the
        surfaces, a runway centerline is needed as a reference for the
        surfaces. This tool generates the surfaces as polygon or multipatch
        features.

     INPUTS:
      in_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      target (Feature Layer):
          The target feature class that will contain the generated obstruction
          identification surfaces.
      runway_direction {String}:
          Specifies at which end of the runway the approach surface will be
          created.

          * HIGH_END_TO_LOW_END-From runway high end to low end. The approach
          surface will be created at the high end of the runway. If a displaced
          threshold point exists at the high end of the runway, that point will
          be honored when creating the OIS.

          * LOW_END_TO_HIGH_END-From runway low end to high end. The approach
          surface will be created at the low end of the runway. If a displaced
          threshold point exists at the low end of the runway, that point will
          be honored when creating the OIS.
      length {Double}:
          The length of the surface in meters. The default value is 900.
      width {Double}:
          The width of the surface in meters. The default value is 120.
      slope {Double}:
          The slope of the surface in degrees. The default value is 3.
      height {Double}:
          The start height of the surface in meters. The default value is 15.24.
      airport_control_point_feature_class {Feature Layer}:
          Supplies x-, y-, and z-geometry for displaced threshold features. If
          displaced thresholds are included, surfaces will be constructed based
          on their x-, y-, and z-geometry instead of their corresponding runway
          feature endpoint."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ICAOAnnex4_aviation(*gp_fixargs((in_features, target, runway_direction, length, width, slope, height, airport_control_point_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('LightSignalClearanceSurface_aviation', None)
def LightSignalClearanceSurface(in_features=None, target=None, runway_direction=None, length=None, divergence=None, slope=None, distance_from_threshold=None, first_papi_light=None, last_papi_light=None, start_height=None, airport_control_point_feature_class=None, surface_position=None):
    """LightSignalClearanceSurface_aviation(in_features, target, {runway_direction}, {length}, {divergence}, {slope}, {distance_from_threshold}, {first_papi_light}, {last_papi_light}, {start_height}, {airport_control_point_feature_class}, {surface_position})

        Creates a Light Signal Clearance Surface (LSCS) based on the FAA
        Engineering Brief (EB) 95.A LSCS determines which objects are vertical
        obstructions. An object
        is considered as vertical obstruction if it penetrates the LSCS.
        Surfaces are used to support planning and design activities.

     INPUTS:
      in_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      target (Feature Layer):
          The target feature class that will contain the generated obstruction
          identification surfaces.
      runway_direction {String}:
          Specifies the end of the runway where the approach surface will be
          created.

          * HIGH_RUNWAY_END_DESIGNATOR-The approach surface will be created at
          the high end of the runway. This is the default.

          * LOW_RUNWAY_END_DESIGNATOR-The approach surface will be created at
          the low end of the runway.
      length {Double}:
          The length of the surface in miles. The default value is 8.
      divergence {Double}:
          The divergence of the surface in degrees. The default value is 14.
      slope {Double}:
          The slope of the surface in degrees. The default value is 1.
      distance_from_threshold {Double}:
          The distance from the threshold in feet. The default value is 1000.
      first_papi_light {Double}:
          The location of the first precision approach path indicator. The
          default value is 60.
      last_papi_light {Double}:
          The location of the last precision approach path indicator. The
          default value is 120.
      start_height {Double}:
          The start height of the surface. The default value is 35.
      airport_control_point_feature_class {Feature Layer}:
          Supplies x-, y-, and z-geometry for displaced threshold features. If
          displaced thresholds are included, surfaces will be constructed based
          on their x-, y-, and z-geometry instead of their corresponding runway
          feature endpoint.
      surface_position {String}:
          Specifies the position of the precision approach path indicator (PAPI)
          lights on either side of a runway. The position of the PAPI lights
          will be used to determine the position of the output surface.

          * SURFACE_GENERATED_ON_LEFT-PAPI lights are on the left approach side
          of the runway. The surface will generate on the left approach side of
          the runway. This is the default.

          * SURFACE_GENERATED_ON_RIGHT-PAPI lights are on the right approach
          side of the runway. The surface will generate on the right approach
          side of the runway."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LightSignalClearanceSurface_aviation(*gp_fixargs((in_features, target, runway_direction, length, divergence, slope, distance_from_threshold, first_papi_light, last_papi_light, start_height, airport_control_point_feature_class, surface_position), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PAPIObstacleClearanceSurface_aviation', None)
def PAPIObstacleClearanceSurface(in_features=None, target=None, runway_direction=None, length=None, divergence=None, slope=None, distance_from_threshold=None, start_height=None, airport_control_point_feature_class=None):
    """PAPIObstacleClearanceSurface_aviation(in_features, target, {runway_direction}, {length}, {divergence}, {slope}, {distance_from_threshold}, {start_height}, {airport_control_point_feature_class})

        Creates a Precision Approach Path Indicator (PAPI) Obstacle Clearance
        Surface (OCS) based on the FAA Engineering Brief (EB) 95.A PAPI OCS
        determines which objects are vertical obstructions. An
        object is considered a vertical obstruction if it penetrates the PAPI
        OCS. Surfaces are used to support planning and design activities.

     INPUTS:
      in_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      target (Feature Layer):
          The target feature class that will contain the generated obstruction
          identification surfaces.
      runway_direction {String}:
          Specifies the end of the runway where the approach surface will be
          created.

          * HIGH_RUNWAY_END_DESIGNATOR-The approach surface will be created at
          the high end of the runway. This is the default

          * LOW_RUNWAY_END_DESIGNATOR-The approach surface will be created at
          the low end of the runway.
      length {Double}:
          The length of the surface in miles. The default value is 4.
      divergence {Double}:
          The divergence of the surface in degrees. The default value is 10.
      slope {Double}:
          The slope of the surface in degrees. The default value is 3.
      distance_from_threshold {Double}:
          The distance from the threshold in feet. The default value is 700.
      start_height {Double}:
          The start height of the surface in feet. The default value is 35.
      airport_control_point_feature_class {Feature Layer}:
          Supplies x-, y-, and z-geometry for displaced threshold features. If
          displaced thresholds are included, surfaces will be constructed based
          on their x-, y-, and z-geometry instead of their corresponding runway
          feature endpoint."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PAPIObstacleClearanceSurface_aviation(*gp_fixargs((in_features, target, runway_direction, length, divergence, slope, distance_from_threshold, start_height, airport_control_point_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UnifiedFacilitiesCriteria_aviation', None)
def UnifiedFacilitiesCriteria(in_runway_features=None, target_ois_features=None, in_wing_type=None, in_service_type=None, in_runway_class=None, in_flight_rule=None, highend_clear_way_length=None, lowend_clear_way_length=None, airport_elevation=None, custom_json_file=None, airport_control_point_feature_class=None):
    """UnifiedFacilitiesCriteria_aviation(in_runway_features, target_ois_features, in_wing_type, in_service_type, in_runway_class, in_flight_rule, {highend_clear_way_length}, {lowend_clear_way_length}, {airport_elevation}, {custom_json_file}, {airport_control_point_feature_class})

        Creates obstruction identification surfaces based on the Unified
        Facilities Criteria (UFC) 3-260-01 that is prescribed by MIL-STD 3007.
        These surfaces provide planning, design, construction, sustainment,
        restoration, and modernization criteria for the United States
        Department of Defense. Surfaces are created as polygon or multipatch
        features.

     INPUTS:
      in_runway_features (Feature Layer):
          The input runway dataset. The feature class must be z-enabled and
          contain polylines.
      target_ois_features (Feature Layer):
          The existing output feature class that will contain the generated UFC
          surfaces.
      in_wing_type (String):
          Specifies the wing type of the aircraft.

          * FIXED-The wing type is fixed.

          * ROTARY-The wing type is rotary.
          If you choose Rotary, the Runway Class parameter will default to Class
          A without affecting the surface generation.
      in_service_type (String):
          Specifies the type of military service.

          * AIRFORCE-The service type is Air Force.

          * ARMY-The service type is Army.

          * NAVY-The service type is Navy.

          * MARINECORPS-The service type is Marine Corps.
      in_runway_class (String):
          Specifies the runway class. Runways are classified as either Class A
          or Class B based on aircraft type.

          * CLASS_A-The runway classification is Class A.

          * CLASS_B-The runway classification is Class B.
      in_flight_rule (String):
          Specifies the flight rule. The rules that govern the procedures for
          conducting flight, either instrument or under visual conditions.

          * INSTRUMENT-The flight rule is instrument flight condition.

          * VISUAL-The flight rule is visual flight condition.
      highend_clear_way_length {Double}:
          The length of the area at the high end of the runway. The unit of
          measurement is based on the input runway features.
      lowend_clear_way_length {Double}:
          The length of the area at the low end of the runway. The unit of
          measurement is based on the input runway features.
      airport_elevation {Double}:
          The highest elevation on any of the runways of the airport. The value
          should be given in the vertical coordinate system linear units of the
          target feature class. If no value is given, the highest point of the
          Input Runway Features parameter will be used.
      custom_json_file {File}:
          The import configuration, in JSON format, that creates the custom OIS.
      airport_control_point_feature_class {Feature Layer}:
          The point features containing an Airport Elevation feature, displaced
          threshold features, or both. Values provided in the Airport Elevation
          parameter will take precedence over these point features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UnifiedFacilitiesCriteria_aviation(*gp_fixargs((in_runway_features, target_ois_features, in_wing_type, in_service_type, in_runway_class, in_flight_rule, highend_clear_way_length, lowend_clear_way_length, airport_elevation, custom_json_file, airport_control_point_feature_class), True)))
        return retval
    except Exception as e:
        raise e


# Charting\Data Exchange toolset
@gptooldoc('ImportAIXM51Message_aviation', None)
def ImportAIXM51Message(in_message_file=None, target_gdb=None, in_tables=None, update_existing_features=None):
    """ImportAIXM51Message_aviation(in_message_file, target_gdb, {in_tables;in_tables...}, {update_existing_features})

        Imports Aeronautical Information Exchange Model (AIXM) version 5.1
        data into an aviation geodatabase.AIXM is a well-established
        information exchange format in the aviation
        domain, and importing data in this format is the first step in the
        creation of an ArcGIS Aviation Charting product.The AIXM format is
        commonly referred to by its acronym in the aviation
        industry rather than the full name of Aviation Information Exchange
        Model. Consequently, the tool name reflects the common usage of the
        acronym.

     INPUTS:
      in_message_file (File):
          The input AIXM 5.1 message.
      target_gdb (Workspace):
          The ArcGIS Aviation Charting schema workspace to import into.
      in_tables {String}:
          The names of tables used to restrict the feature types that will be
          imported.
      update_existing_features {Boolean}:
          Specifies whether existing features will be updated if they exist or
          new features will be inserted.

          * UPDATE_EXISTING-Existing features will be updated.

          * CREATE_NEW-New features will be inserted. This is default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportAIXM51Message_aviation(*gp_fixargs((in_message_file, target_gdb, in_tables, update_existing_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportDOF_aviation', None)
def ImportDOF(in_obstacle_file=None, obstacle_features=None):
    """ImportDOF_aviation(in_obstacle_file, obstacle_features)

        Adds, deletes, and updates the obstacle point features in an input
        obstacle feature class using an input digital obstacle file (DOF).A
        DOF provided by the FAA contains obstruction data for manufactured
        objects that affect domestic aeronautical charting or airport
        products. A DOF contains digital obstacle data within all FAA regions
        in addition to some areas of Canada, Mexico, the Caribbean, the
        Bahamas, and the Pacific. A DOF does not purport to indicate the
        presence of all obstructions that may be encountered during flight.

     INPUTS:
      in_obstacle_file (File):
          A DOF with a .DAT file extension. The contents of the DOF will be used
          to update the obstacle_features parameter values.
      obstacle_features (Feature Layer):
          The point feature class that will contain obstacle information from
          the DOF after execution."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportDOF_aviation(*gp_fixargs((in_obstacle_file, obstacle_features), True)))
        return retval
    except Exception as e:
        raise e


# Charting\Data Management toolset
@gptooldoc('GenerateAirspaceLines_aviation', None)
def GenerateAirspaceLines(in_airspace_features=None, target_airspace_line_features=None, aoi_features=None, preference_table=None, preference=None):
    """GenerateAirspaceLines_aviation(in_airspace_features, target_airspace_line_features, aoi_features, preference_table, preference)

        Adds, modifies, or deletes polyline features from coincident edges of
        airspace polygons.The AirspaceLine polyline feature class included in
        the ArcGIS
        Aviation Charting AIS geodatabase schema has similar attributes to the
        Airspace polygon feature class. Using Arcade expressions, you can
        symbolize and label the lines based on these attributes. The Generate
        Airspace Lines tool uses settings, known as preferences, to define how
        it will process polyline features. These preferences are configured
        using a separate user interface and should be established before
        running the tool.

     INPUTS:
      in_airspace_features (Feature Layer):
          The polygon feature class containing the airspace boundaries.
      target_airspace_line_features (Feature Layer):
          The polyline feature class containing the airspace line data.
      aoi_features (Feature Layer):
          The polygon feature class containing the area of interest (AOI)
          data.The tool will use the selected polygon features to filter which
          airspace lines will be added, modified, or deleted.
      preference_table (Table View):
          The table of preferences that controls how the airspace lines are
          added, modified, or deleted.
      preference (String):
          The name of a selected preference in the preference_table parameter.
          The selected preference controls how the airspace lines are added,
          modified, or deleted."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateAirspaceLines_aviation(*gp_fixargs((in_airspace_features, target_airspace_line_features, aoi_features, preference_table, preference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateAviationCartographicFeatures_aviation', None)
def GenerateAviationCartographicFeatures(source_target_carto_features=None, aoi_features=None, extraction_query_table=None, inclusion_exclusion_table=None):
    """GenerateAviationCartographicFeatures_aviation(source_target_carto_features;source_target_carto_features..., aoi_features, {extraction_query_table}, {inclusion_exclusion_table})

        Creates cartographic copies of features based on the area of interest
        they fall into.Optionally, copies can also be created based on
        attribute queries that
        further refine the criteria for candidate features or manual inclusion
        or exclusion of features.

     INPUTS:
      source_target_carto_features (Value Table):
          Associates source feature classes with the cartographic feature
          classes in which they will be generating features.The first row is the
          source feature class to copy from, and the second
          row is the target cartographic feature class to copy features to.
      aoi_features (Feature Layer):
          A layer of area of interest (AOI) polygon features, that is used to
          spatially filter source features.
      extraction_query_table {Table View}:
          A table of where clauses to further filter source features based on an
          attribute query.
      inclusion_exclusion_table {Table View}:
          A table identifying manually included or excluded source features."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateAviationCartographicFeatures_aviation(*gp_fixargs((source_target_carto_features, aoi_features, extraction_query_table, inclusion_exclusion_table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateDerivedAirspaceGeometry_aviation', None)
def GenerateDerivedAirspaceGeometry(in_airspace_features=None, airspace_association_table=None):
    """GenerateDerivedAirspaceGeometry_aviation(in_airspace_features, airspace_association_table)

        Generates airspace geometry for associated airspace features from an
        imported AIXM 5.1 message.To derive geometry for airspace features
        with null geometry, run the
        Import AIXM 5.1 Message tool before running this tool. The Generate
        Derived Airspace Geometry tool will update the null geometry with a
        polygon derived from other airspace features in the
        AirspaceAssociation table.The Airspace and AirspaceAssociation tables
        are populated by the
        Import AIXM 5.1 Message tool. As populated, the Airspace table
        features are related by the FIRSTMEMBER_ID and SECONDMEMBER_ID fields
        in the AirspaceAssociation table. The OPR_CODE field will relate one
        base airspace feature to one or more other airspace features having
        prescribed OPR_CODE values such as Union, Subtract, Intersect, or Same
        Extent. The tool will process the related airspaces based on the
        OPR_CODE value in the value order in the NUMSEQ_VAL field.

     INPUTS:
      in_airspace_features (Feature Layer):
          The input polygon feature class containing three or more airspace
          features, some or all of which will be used to derive more complex
          airspace features. The derived features will be updated in this target
          feature class.
      airspace_association_table (Table View):
          The input table containing information about the geometric
          associations between two or more airspace features. The airspace
          relationship information stored in this table is populated through the
          AIXM import process."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateDerivedAirspaceGeometry_aviation(*gp_fixargs((in_airspace_features, airspace_association_table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PrepareAviationData_aviation', None)
def PrepareAviationData(target_gdb=None, config_file=None, in_dataset_names=None):
    """PrepareAviationData_aviation(target_gdb, config_file, {in_dataset_names;in_dataset_names...})

        Evaluates aviation data based on organizationally specific JSON
        scripts, returning values necessary for cartographic labeling and
        symbolization. Returned values are stored in a single attribute of
        your features.

     INPUTS:
      target_gdb (Workspace):
          The ArcGIS Aviation Charting schema workspace on which the evaluation
          will be run.
      config_file (File):
          The JSON file containing the evaluation criteria.
      in_dataset_names {String}:
          The names of the tables and feature classes to be evaluated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PrepareAviationData_aviation(*gp_fixargs((target_gdb, config_file, in_dataset_names), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ProcessAirTrafficServiceRoutes_aviation', None)
def ProcessAirTrafficServiceRoutes(in_route_features=None, target_carto_route_features=None, aoi_features=None, preference_table=None, preference=None):
    """ProcessAirTrafficServiceRoutes_aviation(in_route_features, target_carto_route_features, aoi_features, preference_table, preference)

        Identifies, generalizes, and offsets overlapping Air Traffic Service
        (ATS) routes.Using Process ATS Route preferences, this tool allows you
        to identify
        overlapping ATS routes on a chart. Once overlapping ATS routes have
        been identified, the tool uses the provided Process ATS Route
        preferences to generalize or offset the routes.

     INPUTS:
      in_route_features (Feature Layer):
          The polyline feature layer containing air traffic service (ATS) route
          data. This data will be used to update features in the
          target_carto_route_features feature layer.
      target_carto_route_features (Feature Layer):
          The cartographic feature layer containing air traffic service (ATS)
          routes. The attributes of these features will be modified to simplify
          the display of overlapping routes.
      aoi_features (Feature Layer):
          The polygon feature class containing area of interest (AOI) features.
      preference_table (Table View):
          The table of preferences that control how air traffic service (ATS)
          routes are processed.
      preference (String):
          The name of a preference from the preference_table parameter. The
          preference controls how air traffic service (ATS) routes are
          processed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ProcessAirTrafficServiceRoutes_aviation(*gp_fixargs((in_route_features, target_carto_route_features, aoi_features, preference_table, preference), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ReportAviationChartChanges_aviation', None)
def ReportAviationChartChanges(aviation_workspace=None, base_version=None, comparison_version=None, report_preference=None, report_name=None, aoi_features=None):
    """ReportAviationChartChanges_aviation(aviation_workspace, base_version, comparison_version, report_preference, report_name, {aoi_features})

        Compares feature classes in two enterprise geodatabase versions and
        returns the differences in a report. You can filter the reported
        changes to determine which charts are affected by these differing data
        sources. You can set filters based on areas of interest (AOI),
        definition queries, and Report Chart Changes preferences.Once
        generated, the report will be written to the ChartChanges feature
        class in the ArcGIS Aviation Charting AIS geodatabase schema. You can
        name the report and reference it through the SessionID unique report
        identifier. You can use the Chart Changes tool to view the report..

     INPUTS:
      aviation_workspace (Workspace):
          The versioned enterprise ArcGIS Aviation Charting AIS geodatabase.The
          workspace cannot be a file geodatabase.
      base_version (String):
          The version of the ArcGIS Aviation Charting AIS geodatabase to compare
          to.
      comparison_version (String):
          The version of the ArcGIS Aviation Charting AIS geodatabase to compare
          to the base_version parameter value.
      report_preference (String):
          The Report Chart Changes preference setting from the preference
          table.This preference will define which feature classes will be
          included in
          your report.
      report_name (String):
          The unique name of the report, containing changes between the
          geodatabase versions.
      aoi_features {Feature Layer}:
          The boundary within which features will be processed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ReportAviationChartChanges_aviation(*gp_fixargs((aviation_workspace, base_version, comparison_version, report_preference, report_name, aoi_features), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject