# -*- coding: utf-8 -*-
#COPYRIGHT 2020 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Toolbox Indoors Tools"""
__all__ = ['ClassifyIndoorPathways', 'ConfigureIndoorPositioning',
           'CreateIndoorsDatabase', 'GenerateFacilityEntryways',
           'GenerateFloorTransitions', 'GenerateIndoorPathways',
           'GenerateOccupantFeatures', 'GenerateUnitOpenings',
           'ImportBIMToIndoorDataset', 'ImportFloorplansToIndoorsGDB',
           'ThinIndoorPathways']
__alias__ = 'indoors'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('ConfigureIndoorPositioning_indoors', None)
def ConfigureIndoorPositioning(in_geodatabase=None, encryption_key=None, api_key=None, building_id=None):
    """ConfigureIndoorPositioning_indoors(in_geodatabase, encryption_key, api_key, building_id)

        Writes indoor positioning system configuration information to an
        ArcGIS Indoors geodatabase. The values are used by ArcGIS Indoors for
        iOS and ArcGIS Indoors for Android.The tool is only necessary if your
        organization is using the Indoo.rs
        positioning system.

     INPUTS:
      in_geodatabase (Workspace):
          The Indoors file or enterprise geodatabase for which IPS configuration
          information will be generated.
      encryption_key (String):
          The key used by the tool and Indoors mobile apps to encrypt or
          unencrypt the API Key parameter (api_key in Python) value.
      api_key (String):
          A unique value in the form of a GUID used by Indoors mobile apps to
          enable Indoo.rs indoor positioning. The API key is provided by
          Indoo.rs.
      building_id (String):
          A unique alphanumerical value used by Indoors mobile apps to link the
          site in the mobile map package to the Indoo.rs indoor positioning
          survey. The building ID is provided by Indoo.rs."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConfigureIndoorPositioning_indoors(*gp_fixargs((in_geodatabase, encryption_key, api_key, building_id), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateIndoorsDatabase_indoors', None)
def CreateIndoorsDatabase(target_gdb=None, create_network=None):
    """CreateIndoorsDatabase_indoors(target_gdb, {create_network})

        Adds the necessary datasets, feature classes, tables, and
        configurations to a geodatabase to host ArcGIS Indoors data.

     INPUTS:
      target_gdb (Workspace):
          The geodatabase that will contain the ArcGIS Indoors Information Model
          to manage indoor GIS information for use with Indoors apps.
      create_network {Boolean}:
          Specifies whether a network dataset containing the indoor
          transportation network feature classes-Landmarks, Pathways, and Floor
          Transitions-will be created in the Indoors database.

          * CREATE_NETWORK-A network dataset and feature classes will be
          created. This is the default.

          * NO_CREATE_NETWORK-A network dataset and feature classes will not be
          created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateIndoorsDatabase_indoors(*gp_fixargs((target_gdb, create_network), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateOccupantFeatures_indoors', None)
def GenerateOccupantFeatures(in_unit_features=None, unit_id_field=None, in_occupant_table=None, occupant_id_field=None, out_occupant_feature_class=None):
    """GenerateOccupantFeatures_indoors(in_unit_features, unit_id_field, in_occupant_table, occupant_id_field, out_occupant_feature_class)

        Creates or updates employee or occupant point data that conforms to
        the ArcGIS Indoors Information Model.This tool generates point
        features based on input building spaces
        (units) and enriches those points with occupant data. The output of
        this tool can be used to support Indoors mapping and routing.

     INPUTS:
      in_unit_features (Feature Layer):
          The input polygon features representing building spaces that may be
          occupied. In the Indoors Information Model, this is the Units layer.
          The centroid of each space will be used as the point location of the
          occupant or occupants.
      unit_id_field (Field):
          The field in the Input Unit Features that will be used as the primary
          key to associate building spaces with records in the Input Occupant
          Table.
      in_occupant_table (Table View):
          The input table that contains information about building occupants.The
          information can be stored in a geodatabase table, a sheet in an
          Excel workbook (.xls or .xlsx file), or a .csv file.
      occupant_id_field (Field):
          The field in the Input Occupant Table that will be used as the primary
          key to associate occupants with Input Unit Features.

     OUTPUTS:
      out_occupant_feature_class (Feature Class):
          The output feature class created from joining the Input Unit Features
          and Input Occupant Table parameter values."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateOccupantFeatures_indoors(*gp_fixargs((in_unit_features, unit_id_field, in_occupant_table, occupant_id_field, out_occupant_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateUnitOpenings_indoors', None)
def GenerateUnitOpenings(in_unit_features=None, in_detail_features=None, door_detail_expression=None, wall_detail_expression=None, target_openings=None, wall_thickness_tolerance=None, delete_existing_openings=None):
    """GenerateUnitOpenings_indoors(in_unit_features, in_detail_features, door_detail_expression, wall_detail_expression, target_openings, {wall_thickness_tolerance}, {delete_existing_openings})

        Creates unit openings as line features that model the location and
        physical extent of an entrance.This tool analyzes input unit and door
        features to identify entrances,
        such as gates and turnstiles, or physical doors that swing, slide, or
        rotate. Modeling openings as lines simplifies maps by avoiding complex
        door symbology. Straight line features for openings are also a
        requirement for exporting to IMDF.

     INPUTS:
      in_unit_features (Feature Layer):
          The input polygon features representing unit footprints for one or
          more buildings. In the Indoors model, this is the Units layer. The
          tool only processes the building floors that contain the selected
          features.
      in_detail_features (Feature Layer):
          The input polyline features representing the architectural detail
          polylines.
      door_detail_expression (SQL Expression):
          An SQL expression used to identify which detail polylines represent
          doors.
      wall_detail_expression (SQL Expression):
          An SQL expression used to identify which detail polylines represent
          walls.
      target_openings (Feature Layer):
          The existing polyline feature class or feature layer to which
          generated polylines will be written. In the Indoors model this is the
          Details layer.
      wall_thickness_tolerance {Linear Unit}:
          The distance the tool will search inward and outward from the edge of
          a unit feature to find a door feature. The default unit of measurement
          is feet. The default value is 2 feet but can range from 0 to 6 feet.
      delete_existing_openings {Boolean}:
          Specifies whether existing opening features with a USE_TYPE field
          value of Opening will be deleted before creating new opening features.
          If deleted, the tool will replace existing openings with new openings
          if they are at the same location.

          * DELETE_EXISTING-Existing openings will be deleted.

          * KEEP_EXISTING-Existing openings will not be deleted. This is the
          default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateUnitOpenings_indoors(*gp_fixargs((in_unit_features, in_detail_features, door_detail_expression, wall_detail_expression, target_openings, wall_thickness_tolerance, delete_existing_openings), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportBIMToIndoorDataset_indoors', None)
def ImportBIMToIndoorDataset(in_bim_floorplan_layer=None, target_indoor_dataset=None, ground_floor_name=None, building_name=None, room_category_field=None, floors_to_import=None, area_unit_of_measure=None):
    """ImportBIMToIndoorDataset_indoors(in_bim_floorplan_layer, target_indoor_dataset, ground_floor_name, {building_name}, {room_category_field}, {floors_to_import;floors_to_import...}, {area_unit_of_measure})

        Imports features from a BIM file into an indoor dataset.This tool
        imports features directly from a BIM file into an indoor
        dataset that conforms to the ArcGIS Indoors Information Model. The
        output of this tool can be used to create 2D maps and 3D scenes for
        use in floor-aware apps, as well as to generate an indoor network for
        routing.

     INPUTS:
      in_bim_floorplan_layer (Polygon):
          The Floorplan_Polygon feature layer from the source BIM file that has
          been added to the current map.
      target_indoor_dataset (Feature Dataset):
          The target indoor dataset that conforms to the ArcGIS Indoors
          Information Model and contains Facilities, Levels, Units, and Details
          feature classes.
      ground_floor_name (String):
          The ground floor of the building. The vertical order of the levels is
          derived from this input. Any levels with an elevation that is less
          than the specified ground floor are assigned a negative vertical
          order.
      building_name {String}:
          The unique building name assigned to the output Indoors features. The
          default value is the Bldg_Name field value from the input BIM file. If
          the field is null or empty, this parameter is populated with the name
          of the input source file.
      room_category_field {String}:
          The field from the Floorplan_Polygon feature layer that is used to
          populate the USE_TYPE field for the Units feature class in the target
          indoor dataset. If no field is provided, the RoomName field value from
          the Floorplan_Polygon layer is used.
      floors_to_import {String}:
          The floors in the input BIM file that are imported to the target
          indoor dataset. If no floors are provided, all floors are imported.
      area_unit_of_measure {String}:
          Specifies the unit of measure used for the area fields in the
          Facilities, Levels, and Units feature classes.

          * SQUARE_METERS-Area is defined in square meters.

          * SQUARE_FEET-Area is defined in square feet. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportBIMToIndoorDataset_indoors(*gp_fixargs((in_bim_floorplan_layer, target_indoor_dataset, ground_floor_name, building_name, room_category_field, floors_to_import, area_unit_of_measure), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportFloorplansToIndoorsGDB_indoors', None)
def ImportFloorplansToIndoorsGDB(in_geodatabase=None, in_excel_template=None, uniqueid_delimiter=None, sliver_threshold=None, door_close_buffer=None, area_unit_of_measure=None):
    """ImportFloorplansToIndoorsGDB_indoors(in_geodatabase, in_excel_template, uniqueid_delimiter, {sliver_threshold}, {door_close_buffer}, {area_unit_of_measure})

        Imports floor plans from CAD files into a workspace that contains the
        ArcGIS Indoors Information Model.

     INPUTS:
      in_geodatabase (Workspace):
          The Indoors geodatabase (file or enterprise) into which the floor plan
          data will be loaded.
      in_excel_template (File):
          An Excel spreadsheet (.xls or .xlsx file) that contains input and
          configuration parameters.
      uniqueid_delimiter (String):
          Specifies the delimiter that will separate key values in the Indoors
          model hierarchy.

          * PERIOD-The ID will include key values separated by periods. This is
          default.

          * HYPHEN-The ID will include key values separated by hyphens.

          * UNDERSCORE-The ID will include key values separated by underscores.
      sliver_threshold {Long}:
          The ratio of perimeter to area that defines a sliver polygon. It is
          used when importing Unit polygons to improve the quality of the
          imported data. Unit polygons that are determined to be slivers are
          placed in a review geodatabase located in the scratch folder of the
          ArcGIS Pro project. The default value is 2.
      door_close_buffer {Double}:
          The distance, in inches, the tool will search from a door to find and
          snap to the nearest wall. This parameter is used when the CLOSE_DOORS
          column is set to Y in the input Excel template file. The default value
          is 0.
      area_unit_of_measure {String}:
          Specifies the unit of measure used to calculate area for the
          AREA_GROSS and AREA_NET fields when importing floor plans.

          * SQUARE_FEET-Area will be defined in square feet. This is default.

          * SQUARE_METERS-Area will be defined in square meters."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportFloorplansToIndoorsGDB_indoors(*gp_fixargs((in_geodatabase, in_excel_template, uniqueid_delimiter, sliver_threshold, door_close_buffer, area_unit_of_measure), True)))
        return retval
    except Exception as e:
        raise e


# Indoors Network toolset
@gptooldoc('ClassifyIndoorPathways_indoors', None)
def ClassifyIndoorPathways(in_unit_features=None, target_pathways=None):
    """ClassifyIndoorPathways_indoors(in_unit_features, target_pathways)

        Classifies pathways as primary or secondary for routing
        priority.Pathways within the selected space (unit) features are ranked
        as
        secondary, with the remaining ranked as primary. These pathways are
        used to generate a network for routing. Secondary pathways in the
        network are low priority pathways and are only used for routing when
        needed to reach a destination.

     INPUTS:
      in_unit_features (Feature Layer):
          The input polygon features representing spaces within a building for
          which Target Pathways are classified. In the ArcGIS Indoors Model,
          this will be the Units layer.
      target_pathways (Feature Layer):
          The existing feature class or feature layer in which pathways will be
          updated. In the ArcGIS Indoors Model, this is the Pathways layer."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ClassifyIndoorPathways_indoors(*gp_fixargs((in_unit_features, target_pathways), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateFacilityEntryways_indoors', None)
def GenerateFacilityEntryways(in_level_features=None, in_unit_features=None, in_door_features=None, target_entryways=None, buffer_size=None, entryway_use_type=None, exterior_unit_exp=None, delete_existing_entryways=None):
    """GenerateFacilityEntryways_indoors(in_level_features, in_unit_features, in_door_features, target_entryways, {buffer_size}, {entryway_use_type}, {exterior_unit_exp}, {delete_existing_entryways})

        Creates or updates points representing a building's entry or exit
        locations.This tool analyzes input unit features to identify the
        exterior edges
        of a building (facility) and generates point features for doors
        located in proximity to those edges. The ArcGIS Indoors network uses
        these entryway points when routing into, out of, and between
        buildings.

     INPUTS:
      in_level_features (Feature Layer):
          The input polygon features representing a floor or floors in one or
          more buildings. In the Indoors Model, this will be the Levels layer.
          The tool processes only the building floors represented by these
          features.
      in_unit_features (Feature Layer):
          The input polygon features representing building spaces. In the
          Indoors Model, this will be the Units layer. The tool uses these
          features when identifying exterior edges of a building.
      in_door_features (Feature Layer):
          The input polyline features representing doors. In the Indoors
          Model, this will be a subset of features from the Details layer. The
          tool uses these features when identifying entryways along the exterior
          of a building. If the source feature class also contains
          features representing other
          architectural details such as windows or stairs, you must first select
          the features in the layer that represent doors. You can use the Select
          Layer By Attribute tool to make a selection.
      target_entryways (Feature Layer):
          The feature class or feature layer to which generated entryway points
          will be written. In the Indoors Model, this will be the
          PointsOfInterest layer.
      buffer_size {Double}:
          The distance, in meters, the tool will search inward and outward from
          a building's exterior edge to identify potential entryways. The
          default value is 0.5 and can range from 0 to 10.
      entryway_use_type {String}:
          The value used to calculate the USE_TYPE field for new entryway
          points. The default value is Entry.
      exterior_unit_exp {SQL Expression}:
          An SQL expression used to define which Input Unit Features represent a
          building's exterior spaces, such as patios or fire escapes. Spaces
          matching this expression will be treated as exterior during entryway
          generation.
      delete_existing_entryways {Boolean}:
          Specifies whether existing entryway features with a USE_TYPE field
          value matching the entryway_use_type parameter value will be deleted
          before creating new entryway points. When deleting existing entryways,
          the tool only identifies entryways on floors included in the
          in_level_features parameter.

          * DELETE_FEATURES-Existing features will be deleted.

          * NO_DELETE_FEATURES-Existing features will not be deleted. This is
          the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateFacilityEntryways_indoors(*gp_fixargs((in_level_features, in_unit_features, in_door_features, target_entryways, buffer_size, entryway_use_type, exterior_unit_exp, delete_existing_entryways), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateFloorTransitions_indoors', None)
def GenerateFloorTransitions(facility_features=None, transition_unit_features=None, pathway_features=None, target_transitions=None, elevator_delay=None, delete_existing_transitions=None, stairway_unit_exp=None, elevator_unit_exp=None):
    """GenerateFloorTransitions_indoors(facility_features, transition_unit_features, pathway_features, target_transitions, {elevator_delay}, {delete_existing_transitions}, {stairway_unit_exp}, {elevator_unit_exp})

        Creates or updates transition line features that connect floors
        vertically.Selected space (unit) polygons are used to generate a
        vertical line
        between building floors (levels). These transition features are used
        in conjunction with pathway features to generate a network for
        routing.

     INPUTS:
      facility_features (Feature Layer):
          The input polygon features representing a building or buildings. In
          the Indoors model, this is the Facilities layer. The tool processes
          only the buildings represented by these features.
      transition_unit_features (Feature Layer):
          The input polygon features representing the transition spaces in a
          building. In the Indoors model, this is the Units layer.
      pathway_features (Feature Layer):
          The input polyline features representing preliminary pathways. The new
          transition features will snap to these polyline features. In the
          Indoors model, this will be the PrelimPathways layer.
      target_transitions (Feature Layer):
          An existing feature class or layer that is updated with the new
          transitions. In the Indoors model, this is the PrelimTransitions
          layer.
      elevator_delay {Long}:
          The average elevator transit time. It is one-half the time in seconds
          that an elevator passenger can expect to spend waiting to enter and
          exit the elevator. Using this parameter can improve routing and
          transit time calculations. The value must be equal to or greater than
          zero.
      delete_existing_transitions {Boolean}:
          Specifies whether existing transition features in selected transition
          spaces will be deleted before creating new transition features. If
          this parameter is not used, updated_transitions will include both
          existing and newly created transition features.

          * DELETE_FEATURES-Existing transition features will be deleted. This
          is the default.

          * NO_DELETE_FEATURES-Existing transition features will not be deleted.
      stairway_unit_exp {SQL Expression}:
          An SQL expression used to define which Transition Unit Features
          represent step-based transitions, such as stairs and escalators.
      elevator_unit_exp {SQL Expression}:
          An SQL expression used to define which Transition Unit Features
          represent lift-based transitions, such as elevators."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateFloorTransitions_indoors(*gp_fixargs((facility_features, transition_unit_features, pathway_features, target_transitions, elevator_delay, delete_existing_transitions, stairway_unit_exp, elevator_unit_exp), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateIndoorPathways_indoors', None)
def GenerateIndoorPathways(in_level_features=None, in_detail_features=None, target_pathways=None, lattice_rotation=None, lattice_density=None, restricted_unit_features=None, restricted_unit_exp=None, detail_exp=None):
    """GenerateIndoorPathways_indoors(in_level_features, in_detail_features, target_pathways, {lattice_rotation}, {lattice_density}, {restricted_unit_features}, {restricted_unit_exp}, {detail_exp})

        Generates preliminary pathways that are cut according to obstructions,
        such as walls or columns, on selected floors in one or more buildings
        (facilities).Once stair or elevator floor transitions are added, the
        Thin Indoor
        Pathways tool is used to create the final indoor network dataset.

     INPUTS:
      in_level_features (Feature Layer):
          The input polygon features representing building floors. In the
          Indoors model, this will be the Levels layer. The tool honors
          selections and definition queries applied to the layer.
      in_detail_features (Feature Layer):
          The input polyline features representing architectural details that
          may serve as barriers to travel within a building. In the Indoors
          model, this will be the Details layer
      target_pathways (Feature Layer):
          The Indoors geodatabase (file or enterprise) feature class or feature
          layer to which generated pathway polylines will be written. In the
          Indoors model, this will be the PrelimPathways layer.
      lattice_rotation {Double}:
          The number of degrees by which the input floors' primary travel
          direction is rotated clockwise from due west. If left blank, the tool
          will calculate a value based on the minimum bounding rectangle of each
          floor.The value must be between 0.0 and 180.0.
      lattice_density {Double}:
          The longest distance, in meters, allowed between nodes in the
          generated lattice of pathways. The default value is 0.6.The value must
          be between 0.25 and 0.9.
      restricted_unit_features {Feature Layer}:
          The input polygon features representing restricted and unrestricted
          spaces within a building. In the Indoors model, this will be the Units
          layer.
      restricted_unit_exp {SQL Expression}:
          An SQL expression used to select Restricted Unit Features in which the
          tool should not generate pathways.
      detail_exp {SQL Expression}:
          An SQL expression used to select Input Detail Features across which
          the tool should not generate pathways."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateIndoorPathways_indoors(*gp_fixargs((in_level_features, in_detail_features, target_pathways, lattice_rotation, lattice_density, restricted_unit_features, restricted_unit_exp, detail_exp), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ThinIndoorPathways_indoors', None)
def ThinIndoorPathways(in_level_features=None, in_pathway_features=None, in_transition_features=None, routable_locations=None, target_pathways=None, target_transitions=None, search_tolerance=None, neighbor_solve_count=None):
    """ThinIndoorPathways_indoors(in_level_features, in_pathway_features, in_transition_features, routable_locations;routable_locations..., target_pathways, target_transitions, {search_tolerance}, {neighbor_solve_count})

        Removes preliminary network pathways that are not needed for routing
        between selected locations on each floor, reducing the network dataset
        size and improving its route-solving performance.

     INPUTS:
      in_level_features (Feature Layer):
          The input polygon features representing a floor or floors in one or
          more buildings (facilities). In the Indoors Model, this will be the
          Levels layer. The tool processes only the floors (levels) represented
          by these features.
      in_pathway_features (Feature Layer):
          The input polyline features representing the preliminary pathways to
          be thinned. In the Indoors Model, this will be the PrelimPathways
          layer.
      in_transition_features (Feature Layer):
          The input polyline features representing the preliminary transitions
          to be thinned. In the Indoors Model, this will be the
          PrelimTransitions layer.
      routable_locations (Feature Layer):
          The input point or polygon features representing the locations used to
          calculate routes. In the Indoors Model, this will be the
          PointsOfInterest layer or the Units layer.
      target_pathways (Feature Layer):
          The existing feature class or feature layer to which the thinned
          pathways will be added. In the Indoors Model, this will be the
          Pathways layer.
      target_transitions (Feature Layer):
          The existing feature class or feature to which thinned transitions
          will be added. In the Indoors Model, this will be the Transitions
          layer.
      search_tolerance {Long}:
          The distance, in meters, the tool will search for Routable
          Locations features near the input pathways. Routable Locations
          features farther away than this value will not be used for thinning.
          The default value is 5. The value must be 0 or greater.
      neighbor_solve_count {Long}:
          The number of closest neighboring locations to solve when
          calculating routes between a given location and other routable
          locations in the building (facility). The default value is 50.
          The value must be 1 or greater."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ThinIndoorPathways_indoors(*gp_fixargs((in_level_features, in_pathway_features, in_transition_features, routable_locations, target_pathways, target_transitions, search_tolerance, neighbor_solve_count), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject